package com.cqut.stack.bn.controller;

import com.cqut.stack.bn.pojo.dto.areaEvaluate.ImportAreaEvaluateInfoDTO;
import com.cqut.stack.bn.pojo.dto.areaHandle.GetAreaEvaluateInfoDTO;
import com.cqut.stack.bn.pojo.dto.areaHandle.ImportAreaHandleInfoDTO;
import com.cqut.stack.bn.pojo.dto.characteristicThing.GetCharacteristicThingInfoDTO;
import com.cqut.stack.bn.pojo.dto.characteristicThing.GetCharacteristicThingInfoListByPageDTO;
import com.cqut.stack.bn.pojo.dto.characteristicThing.ImportCharacteristicThingDTO;
import com.cqut.stack.bn.pojo.dto.efficientThing.GetEfficientThingInfoDTO;
import com.cqut.stack.bn.pojo.dto.efficientThing.GetEfficientThingInfoListByPageDTO;
import com.cqut.stack.bn.pojo.dto.electronicCertificate.GetElectronicCertificateInfoDTO;
import com.cqut.stack.bn.pojo.dto.electronicCertificate.GetElectronicCertificateInfoListByPageDTO;
import com.cqut.stack.bn.pojo.dto.electronicCertificate.ImportElectronicCertificateInfoDTO;
import com.cqut.stack.bn.pojo.dto.electronicSeal.GetElectronicSealInfoDTO;
import com.cqut.stack.bn.pojo.dto.electronicSeal.GetElectronicSealInfoListDTOByPageDTO;
import com.cqut.stack.bn.pojo.dto.electronicSeal.ImportElectronicSealInfoDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.GetFourOfficeInfoDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.GetFourOfficeInfoListByPageDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.ImportFourOfficeInfoDTO;
import com.cqut.stack.bn.pojo.entity.CharacteristicThing;
import com.cqut.stack.bn.pojo.entity.EfficientThing;
import com.cqut.stack.bn.pojo.entity.ElectronicCertificate;
import com.cqut.stack.bn.pojo.entity.ElectronicSeal;
import com.cqut.stack.bn.pojo.entity.*;
import com.cqut.stack.bn.pojo.vo.areaEvaluate.GetAreaEvaluateInfoVO;
import com.cqut.stack.bn.pojo.vo.areaHandle.GetAreaHandleInfoVO;
import com.cqut.stack.bn.pojo.vo.characteristicThing.GetCharacteristicThingInfoVO;
import com.cqut.stack.bn.pojo.vo.efficientThing.GetEfficientThingInfoVO;
import com.cqut.stack.bn.pojo.vo.electronicCertificate.GetElectronicCertificateInfoVO;
import com.cqut.stack.bn.pojo.vo.electronicSeal.GetElectronicSealInfoVO;
import com.cqut.stack.bn.service.*;
import com.cqut.stack.bn.util.jsonResult.CodeMessage;
import com.cqut.stack.bn.util.jsonResult.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Api(tags = "政务服务")
@RequestMapping("/api/governmentService")
public class GovernmentServiceController {

    @Resource
    private ElectronicSealService electronicSealService;

    @Resource
    private ElectronicCertificateService electronicCertificateService;

    @Resource
    private EfficientThingService efficientThingService;

    @Resource
    private CharacteristicThingService characteristicThingService;

    @Resource
    private FourOfficeInfoService fourOfficeInfoService;

    @Resource
    private AreaEvaluateService areaEvaluateService;

    @Resource
    private AreaHandleService areaHandleService;
    //****************************************** 可视化大屏开始*******************************************
    @ApiOperation(value = "获取区域评价信息")
    @PostMapping("/getAreaEvaluateInfo")
    public Result<List<GetAreaEvaluateInfoVO>> getAreaEvaluateInfo(){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,areaEvaluateService.areaEvaluateService());
    }

    @ApiOperation(value = "获取区域办件信息")
    @PostMapping("/getAreaHandleInfo")
    public Result<GetAreaHandleInfoVO> getAreaHandleInfo(@RequestBody GetAreaEvaluateInfoDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,areaHandleService.getAreaHandleInfo(dto));
    }

    @ApiOperation(value = "获取电子印章信息")
    @PostMapping("/getElectronicSealInfo")
    public Result<GetElectronicSealInfoVO> getElectronicSealInfo(@RequestBody GetElectronicSealInfoDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,electronicSealService.getElectronicSealInfo(dto));
    }

    @ApiOperation(value = "获取电子证照信息")
    @PostMapping("/getElectronicCertificateInfo")
    public Result<GetElectronicCertificateInfoVO> getElectronicCertificateInfo(@Validated @RequestBody GetElectronicCertificateInfoDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,electronicCertificateService.getElectronicCertificateInfo(dto));
    }

    @ApiOperation(value = "获取高效办成一件事信息")
    @PostMapping("/getEfficientThingInfo")
    public Result<GetEfficientThingInfoVO> getEfficientThingInfo(@Validated @RequestBody GetEfficientThingInfoDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,efficientThingService.getEfficientThingInfo(dto));
    }

    @ApiOperation(value = "获取地方特色一件事信息")
    @PostMapping("/getCharacteristicThingInfo")
    public Result<GetCharacteristicThingInfoVO> getCharacteristicThingInfo(@Validated @RequestBody GetCharacteristicThingInfoDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,characteristicThingService.getCharacteristicThingInfo(dto));
    }

    @ApiOperation(value = "获取四办情况信息")
    @PostMapping("/getFourOfficeInfo")
    public Result<List<FourOfficeInfo>> getFourOfficeInfo(@Validated @RequestBody GetFourOfficeInfoDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,fourOfficeInfoService.getFourOfficeInfo(dto));
    }

    //****************************************** 可视化大屏结束*******************************************

    //****************************************** 后台系统开始*******************************************
    @ApiOperation(value = "电子证照信息分页查询")
    @PostMapping("/getElectronicCertificateInfoByPage")
    public Result<List<ElectronicCertificate>> getElectronicCertificateInfoListByPage(@Validated @RequestBody GetElectronicCertificateInfoListByPageDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,electronicCertificateService.getElectronicCertificateInfoListByPage(dto));
    }

    @ApiOperation(value = "电子印章信息分页查询")
    @PostMapping("/getElectronicSealInfoListByPage")
    public Result<List<ElectronicSeal>> getElectronicSealInfoListByPage(@RequestBody GetElectronicSealInfoListDTOByPageDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,electronicSealService.getElectronicSealInfoListByPage(dto));
    }

    @ApiOperation(value = "高效办成一件事分页查询")
    @PostMapping("/getEfficientThingInfoListByPage")
    public Result<List<EfficientThing>> getEfficientThingInfoListByPage(@RequestBody GetEfficientThingInfoListByPageDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,efficientThingService.getEfficientThingInfoListByPage(dto));
    }

    @ApiOperation(value = "地方特色一件事分页查询")
    @PostMapping("/getCharacteristicThingInfoListByPage")
    public Result<List<CharacteristicThing>> getCharacteristicThingInfoListByPage(@RequestBody GetCharacteristicThingInfoListByPageDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,characteristicThingService.getCharacteristicThingInfoListByPage(dto));
    }

    @ApiOperation(value = "四办情况分页查询")
    @PostMapping("/getFourOfficeInfoListByPage")
    public Result<List<FourOfficeInfo>> getFourOfficeInfoListByPage(@RequestBody GetFourOfficeInfoListByPageDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,fourOfficeInfoService.getFourOfficeInfoListByPage(dto));
    }

    //****************************************** 后台系统结束 *******************************************


    //****************************************** Excel数据同步开始 *******************************************
    @ApiOperation(value = "导入电子印章信息")
    @PostMapping("/importElectronicSealInfo")
    public Result<?> importElectronicSealInfo(@Validated ImportElectronicSealInfoDTO dto){
        electronicSealService.importElectronicSealInfo(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入电子证照信息")
    @PostMapping("/importElectronicCertificateInfo")
    public Result<?> importElectronicCertificateInfo(@Validated ImportElectronicCertificateInfoDTO dto){
        electronicCertificateService.importElectronicCertificateInfo(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入四办情况信息")
    @PostMapping("/importFourOfficeInfo")
    public Result<?> importFourOfficeInfo(@Validated ImportFourOfficeInfoDTO dto){
        fourOfficeInfoService.importFourOfficeInfo(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入高效办成一件事信息")
    @PostMapping("/importEfficientThingInfo")
    public Result<?> importEfficientThingInfo(@Validated ImportAreaHandleInfoDTO dto){
        efficientThingService.importEfficientThingInfo(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入地方特色一件事信息")
    @PostMapping("/importCharacteristicThing")
    public Result<?> importCharacteristicThing(@Validated ImportCharacteristicThingDTO dto){
        characteristicThingService.importCharacteristicThing(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入区域评价信息")
    @PostMapping("/importAreaEvaluateInfo")
    public Result<?> importAreaEvaluateInfo(@Validated ImportAreaEvaluateInfoDTO dto){
        areaEvaluateService.importAreaEvaluateInfo(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入区域办件信息")
    @PostMapping("/importAreaHandleInfo")
    public Result<?> importAreaHandleInfo(@Validated ImportAreaHandleInfoDTO dto){
        areaHandleService.importAreaHandleInfo(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    //****************************************** Excel数据同步结束 *******************************************
}
