package com.cqut.stack.bn.controller;


import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDailyAcceptance.DateDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDeptAcceptance.GetHotlineDeptAcceptanceDTO;
import com.cqut.stack.bn.pojo.dto.hotlineAcceptance.GetCurrentAreaHotlineAcceptanceDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDeptAcceptance.GetMunicipalDeptAcceptInfoDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDistrictAcceptance.GetHotlineDistrictAcceptInfoDTO;
import com.cqut.stack.bn.pojo.entity.*;
import com.cqut.stack.bn.pojo.dto.workOrder.GetWorkOrderDetailDTO;
import com.cqut.stack.bn.pojo.dto.workOrder.GetWorkOrderResourceTypeDTO;
import com.cqut.stack.bn.pojo.dto.workOrderCirculation.GetWorkOrderCirculationDTO;
import com.cqut.stack.bn.pojo.entity.HotlineAcceptance;
import com.cqut.stack.bn.pojo.entity.WordOrderDetail;
import com.cqut.stack.bn.pojo.entity.WorkOrder;
import com.cqut.stack.bn.pojo.entity.WorkOrderCirculation;
import com.cqut.stack.bn.pojo.vo.hotlineDeptAcceptance.GetMunicipalDeptAcceptInfoVO;
import com.cqut.stack.bn.pojo.vo.hotlineDailyAcceptance.GetRecentlyAcceptCountTrendVO;
import com.cqut.stack.bn.pojo.vo.hotlineDailyAcceptance.GetHistoryAcceptCountVO;
import com.cqut.stack.bn.pojo.vo.hotlineDistrictAcceptance.GetHotlineDistrictAcceptInfoVO;
import com.cqut.stack.bn.pojo.vo.todayAcceptance.GetTodayAcceptanceInfoVO;
import com.cqut.stack.bn.pojo.vo.workOrder.GetWorkOrderResourceTypVO;
import com.cqut.stack.bn.service.*;
import com.cqut.stack.bn.util.jsonResult.CodeMessage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.cqut.stack.bn.util.jsonResult.Result;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Api(tags = "12345")
@RequestMapping("/api/12345")
public class HotlineController {
    @Resource
    private HotlineDailyAcceptanceService hotlineDailyAcceptanceService;

    @Resource
    private HotlineDeptAcceptanceService hotlineDeptAcceptanceService;

    @Resource
    private HotlineDistrictAcceptanceService hotlineDistrictAcceptanceService;

    @Resource
    private HotlineAcceptanceService hotlineAcceptanceService;

    @Resource
    private TodayAcceptanceService todayAcceptanceService;

    @Resource
    private WorkOrderService workOrderService;

    @Resource
    private WordOrderDetailService wordOrderDetailService;

    @Resource
    private WorkOrderCirculationService workOrderCirculationService;

    @Resource
    private DistrictHandleService districtHandleService;

    //****************************************** 可视化大屏开始*******************************************
    @ApiOperation(value = "获取历史接件量")
    @PostMapping("/getHistoryAcceptCount")
    public Result<GetHistoryAcceptCountVO> getHistoryAcceptCount(){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,hotlineDailyAcceptanceService.getHistoryAcceptCount());
    }

    @ApiOperation(value = "获取近12个月历史接件量趋势")
    @PostMapping("/getRecentlyAcceptCountTrend")
    public Result<GetRecentlyAcceptCountTrendVO> getRecentlyAcceptCountTrend() {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, hotlineDailyAcceptanceService.getRecentlyAcceptCountTrend());
    }

    @ApiOperation(value = "获取市级各部门办件情况")
    @PostMapping("/getMunicipalDeptAcceptInfo")
    public Result<GetMunicipalDeptAcceptInfoVO> getMunicipalDeptAcceptInfo(@RequestBody GetMunicipalDeptAcceptInfoDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, hotlineDeptAcceptanceService.getMunicipalDeptAcceptInfo(dto));
    }

    @ApiOperation(value = "获取各区县办件情况")
    @PostMapping("/getHotlineDistrictAcceptInfo")
    public Result<GetHotlineDistrictAcceptInfoVO> getHotlineDistrictAcceptInfo(@RequestBody GetHotlineDistrictAcceptInfoDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, hotlineDistrictAcceptanceService.getHotlineDistrictAcceptInfo(dto));
    }

    @ApiOperation(value = "获取今日话务情况")
    @PostMapping("/getTodayAcceptanceInfo")
    public Result<GetTodayAcceptanceInfoVO> getTodayAcceptanceInfo() {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, todayAcceptanceService.getTodayAcceptanceInfo());
    }

    @ApiOperation(value = "获取工单受理列表")
    @PostMapping("/getWorkOrderList")
    public Result<List<WorkOrder>> getWorkOrderList() {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, workOrderService.getWorkOrderList());
    }

    @ApiOperation(value = "获取工单详情")
    @PostMapping("/getWorkOrderDetail")
    public Result<WordOrderDetail> getWorkOrderDetail(@RequestBody @Validated GetWorkOrderDetailDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, wordOrderDetailService.getWorkOrderDetail(dto));
    }

    @ApiOperation(value = "获取工单流转明细")
    @PostMapping("/getWorkOrderCirculation")
    public Result<WorkOrderCirculation> getWorkOrderCirculation(@RequestBody @Validated GetWorkOrderCirculationDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, workOrderCirculationService.getWorkOrderCirculation(dto));
    }

    @ApiOperation(value = "获取工单来源统计")
    @PostMapping("/getWorkOrderResourceType")
    public Result<GetWorkOrderResourceTypVO> getWorkOrderResourceType(@RequestBody GetWorkOrderResourceTypeDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, workOrderService.getWorkOrderResourceType(dto));
    }


    @ApiOperation(value = "获取当前区县热线办件情况")
    @PostMapping("/getCurrentAreaHotlineAcceptance")
    public Result<List<HotlineAcceptance>> getCurrentAreaHotlineAcceptance(@RequestBody GetCurrentAreaHotlineAcceptanceDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, hotlineAcceptanceService.getCurrentAreaHotlineAcceptance(dto));
    }

    //****************************************** 可视化大屏结束*******************************************

    //****************************************** 后台系统开始*******************************************
    @ApiOperation(value = "12345便民热线每日办件分页查询")
    @PostMapping("/getHotlineDailyAcceptance")
    public Result<List<HotlineDailyAcceptance>> getHotlineDailyAcceptance(@RequestBody DateDTO dateDTO) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, hotlineDailyAcceptanceService.getHotlineDailyAcceptance(dateDTO));
    }

    @ApiOperation(value = "12345便民热线部门办件分页查询")
    @PostMapping("/getHotlineDeptAcceptance")
    public Result<List<HotlineDeptAcceptance>> getHotlineDeptAcceptance(@RequestBody GetHotlineDeptAcceptanceDTO getHotlineDeptAcceptanceDTO ) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, hotlineDeptAcceptanceService.getHotlineDeptAcceptance(getHotlineDeptAcceptanceDTO));
    }

    @ApiOperation(value = "12345便民热线区县办件分页查询")
    @PostMapping("/getHotlineDistrictAcceptance")
    public Result<List<HotlineDistrictAcceptance>> getHotlineDistrictAcceptance(@RequestBody GetHotlineDeptAcceptanceDTO getHotlineDeptAcceptanceDTO ) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, hotlineDistrictAcceptanceService.getHotlineDistrictAcceptance(getHotlineDeptAcceptanceDTO));
    }

    @ApiOperation(value = "hotline_acceptance分页查询")
    @PostMapping("/getHotlineAcceptance")
    public Result<List<HotlineAcceptance>> getHotlineAcceptance(@RequestBody GetHotlineDeptAcceptanceDTO getHotlineDeptAcceptanceDTO ) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, hotlineAcceptanceService.getHotlineAcceptance(getHotlineDeptAcceptanceDTO));
    }

    @ApiOperation(value = "区县受理、交办量分页查询")
    @PostMapping("/getDistrictHandle")
    public Result<List<DistrictHandle>> getDistrictHandle(@RequestBody DateDTO dateDTO ) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, districtHandleService.getDistrictHandle(dateDTO));
    }

    @ApiOperation(value = "今日话务情况分页查询")
    @PostMapping("/getTodayAcceptance")
    public Result<List<TodayAcceptance>> getTodayAcceptance(@RequestBody DateDTO dateDTO ) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, todayAcceptanceService.getTodayAcceptance(dateDTO));
    }

    @ApiOperation(value = "工作受理列表分页查询")
    @PostMapping("/getWorkOrder")
    public Result<List<WorkOrder>> getWorkOrder(@RequestBody DateDTO dateDTO ) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, workOrderService.getWorkOrder(dateDTO));
    }

    @ApiOperation(value = "工作受理详情分页查询")
    @PostMapping("/getWordOrderDetail")
    public Result<List<WordOrderDetail>> getWordOrderDetail(@RequestBody DateDTO dateDTO ) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, wordOrderDetailService.getWordOrderDetail(dateDTO));
    }

    @ApiOperation(value = "工作流转明细分页查询")
    @PostMapping("/getWorkOrderCirculationList")
    public Result<List<WorkOrderCirculation>> getWorkOrderCirculationList(@RequestBody DateDTO dateDTO ) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, workOrderCirculationService.getWorkOrderCirculationList(dateDTO));
    }

    //****************************************** 后台系统结束*******************************************


    //****************************************** Excel数据同步开始 *******************************************
    @ApiOperation(value = "导入12345便民热线每日办件")
    @PostMapping("/importHotlineDailyAcceptance")
    public Result<?> importHotlineDailyAcceptance(@RequestBody @Validated ExcelImportDTO dto) {
        hotlineDailyAcceptanceService.importHotlineDailyAcceptance(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入12345便民热线部门办件")
    @PostMapping("/importHotlineDeptAcceptance")
    public Result<?> importHotlineDeptAcceptance(@RequestBody @Validated ExcelImportDTO dto) {
        hotlineDeptAcceptanceService.importHotlineDeptAcceptance(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入12345便民热线区县办件")
    @PostMapping("/importHotlineDistrictAcceptance")
    public Result<?> importHotlineDistrictAcceptance(@RequestBody @Validated ExcelImportDTO dto) {
        hotlineDistrictAcceptanceService.importHotlineDistrictAcceptance(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入区县热线交办情况")
    @PostMapping("/importHotlineAcceptance")
    public Result<?> importHotlineAcceptance(@RequestBody @Validated ExcelImportDTO dto) {
        hotlineAcceptanceService.importHotlineAcceptance(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入区县受理、交办量")
    @PostMapping("/importDistrictHandle")
    public Result<?> importDistrictHandle(@RequestBody @Validated ExcelImportDTO dto) {
        districtHandleService.importDistrictHandle(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入今日话务情况")
    @PostMapping("/importTodayAcceptance")
    public Result<?> importTodayAcceptance(@RequestBody @Validated ExcelImportDTO dto) {
        todayAcceptanceService.importTodayAcceptance(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入工作受理列表")
    @PostMapping("/importWorkOrder")
    public Result<?> importWorkOrder(@RequestBody @Validated ExcelImportDTO dto) {
        workOrderService.importWorkOrder(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入工作受理详情")
    @PostMapping("/importWordOrderDetail")
    public Result<?> importWordOrderDetail(@RequestBody @Validated ExcelImportDTO dto) {
        wordOrderDetailService.importWordOrderDetail(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入工作流转明细")
    @PostMapping("/importWorkOrderCirculationList")
    public Result<?> importWorkOrderCirculationList(@RequestBody @Validated ExcelImportDTO dto) {
        workOrderCirculationService.importWorkOrderCirculationList(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }
    //****************************************** Excel数据同步结束 *******************************************


}

