package com.cqut.stack.bn.controller;

import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.resourceTrade.*;
import com.cqut.stack.bn.pojo.entity.AreaTransaction;
import com.cqut.stack.bn.pojo.entity.ResourceTransaction;
import com.cqut.stack.bn.pojo.vo.resourceTrade.GetCategoryTradeInfoVO;
import com.cqut.stack.bn.pojo.vo.resourceTrade.GetCategoryTradeProportionVO;
import com.cqut.stack.bn.pojo.vo.resourceTrade.GetHistoryTradeInfoVO;
import com.cqut.stack.bn.pojo.vo.resourceTrade.GetRecentlyCategoryTradeTrendVO;
import com.cqut.stack.bn.service.AreaTransactionService;
import com.cqut.stack.bn.service.ResourceTransactionService;
import com.cqut.stack.bn.util.jsonResult.CodeMessage;
import com.cqut.stack.bn.util.jsonResult.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Api(tags = "公共资源交易中心")
@RequestMapping("/api/resourceTrade")
public class ResourceTradeController {

    @Resource
    private AreaTransactionService areaTransactionService;

    @Resource
    private ResourceTransactionService resourceTransactionService;

    //****************************************** 可视化大屏开始*******************************************
    @ApiOperation(value = "获取历史交易情况")
    @PostMapping("/getHistoryTradeInfo")
    public Result<GetHistoryTradeInfoVO> getHistoryTradeInfo(@RequestBody GetHistoryTradeInfoDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,areaTransactionService.getHistoryTradeInfo(dto));
    }

    @ApiOperation(value = "获取分类交易情况")
    @PostMapping("/getCategoryTradeInfo")
    public Result<List<GetCategoryTradeInfoVO>> getCategoryTradeInfo(@RequestBody GetCategoryTradeInfoDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,areaTransactionService.getCategoryTradeInfo(dto));
    }

    @ApiOperation(value = "获取交易类别占比")
    @PostMapping("/getCategoryTradeProportion")
    public Result<GetCategoryTradeProportionVO> getCategoryTradeProportion(@RequestBody GetCategoryTradeProportionDTO dto){
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS,areaTransactionService.getCategoryTradeProportion(dto));
    }

    @ApiOperation(value = "获取近12个月历史交易趋势")
    @PostMapping("/getRecentlyCategoryTradeTrend")
    public Result<GetRecentlyCategoryTradeTrendVO> getRecentlyCategoryTradeTrend(@RequestBody GetRecentlyCategoryTradeTrendDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, areaTransactionService.getRecentlyCategoryTradeTrend(dto));
    }

    @ApiOperation(value = "获取公共资源交易列表")
    @PostMapping("/getResourceTransactionList")
    public Result<List<ResourceTransaction>> getResourceTransactionList() {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, resourceTransactionService.getResourceTransactionList());
    }

    @ApiOperation(value = "获取当前区县交易情况情况")
    @PostMapping("/getCurrentAreaTradeInfo")
    public Result<AreaTransaction> getCurrentAreaTradeInfo(@RequestBody GetCurrentAreaTradeInfoDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, areaTransactionService.getCurrentAreaTradeInfo(dto));
    }

    //****************************************** 可视化大屏结束*******************************************


    //****************************************** 后台系统开始*******************************************
    @ApiOperation(value = "区域交易情况")
    @PostMapping("/getAreaTransactionList")
    public Result<List<AreaTransaction>> getAreaTransactionList(@RequestBody GetAreaTransactionDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, areaTransactionService.getAreaTransactionList(dto));
    }

    @ApiOperation(value = "公共资源交易情况")
    @PostMapping("/getResourceTransactionsList")
    public Result<List<ResourceTransaction>> getResourceTransactionsList(@RequestBody GetResourceTransactionsDTO dto) {
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS, resourceTransactionService.getResourceTransactionsList(dto));
    }

    //****************************************** 后台系统开始*******************************************


    //****************************************** Excel数据同步开始 *******************************************
    @ApiOperation(value = "导入公共资源交易详情")
    @PostMapping("/importResourceTransactionDetail")
    public Result<?> importResourceTransactionDetail(@RequestBody @Validated ExcelImportDTO dto) {
        resourceTransactionService.importResourceTransactionDetail(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }

    @ApiOperation(value = "导入公共资源交易信息")
    @PostMapping("/importResourceTransactionInfo")
    public Result<?> importResourceTransactionInfo(@RequestBody @Validated ExcelImportDTO dto) {
        areaTransactionService.importResourceTransactionInfo(dto);
        return Result.buildSuccessResult(CodeMessage.S_SUCCESS);
    }
    //****************************************** Excel数据同步结束 *******************************************
}
