package com.cqut.stack.bn.controller;

import com.cqut.stack.bn.service.UserService;
import com.cqut.stack.bn.pojo.dto.user.ChangeUserRoleInputDTO;
import com.cqut.stack.bn.pojo.dto.user.InsertUserInputDTO;
import com.cqut.stack.bn.pojo.dto.user.UpdatePasswordInputDTO;
import com.cqut.stack.bn.util.jsonResult.JSONResult;
import com.cqut.stack.bn.pojo.global.PaginationDTO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@RestController
@RequestMapping("/user")
@CrossOrigin
@Api(tags = "用户管理")
public class UserController {

    @Autowired
    private UserService userService;

    @ApiOperation("新增用户")
    @PostMapping(value = "/insertUser")
    public JSONResult insertUser(@Validated @RequestBody InsertUserInputDTO input) {
        return new JSONResult(userService.insertUser(input));
    }

    /**
     * 选取用户列表
     * @param input
     * @return
     */
    @GetMapping(value = "/selectUserList")
    public JSONResult selectUserList(@Valid PaginationDTO input){
        return new JSONResult(userService.selectUserList(input));
    }

    /**
     * 更改用户状态
     * @param userId
     * @return
     */
    @PostMapping(value = "/changeUserStatus/{userId}")
    public JSONResult changeUserStatus(@PathVariable String userId){
        return new JSONResult(userService.changeUserStatus(userId));
    }

    /**
     * 更改用户角色
     * @param input
     * @return
     */
    @PostMapping(value = "/changeUserRole")
    public JSONResult changeUserRole(@Valid @RequestBody ChangeUserRoleInputDTO input){
        return new JSONResult(userService.changeUserRole(input));
    }

    /**
     * 删除用户信息
     * @param userId
     * @return
     */
    @PostMapping("/deleteUser/{userId}")
    public JSONResult deleteUser(@PathVariable String userId){
        return new JSONResult(userService.deleteUser(userId));
    }

    /**
     * 根据用户ID查询用户
     * @param userId
     * @return
     */
    @GetMapping("/selectByUserId/{userId}")
    public JSONResult selectByUserId(@PathVariable String userId){
        return new JSONResult(userService.selectByUserId(userId));
    }

    /**
     * 选取角色列表
     * @return
     */
    @GetMapping("/selectRoleList")
    public JSONResult selectRoleList(){
        return new JSONResult(userService.selectRoleList());
    }

    /**
     * 系统用户修改密码
     * @param input
     * @return
     */
    @PostMapping("/updatePassword")
    public JSONResult updatePassword(@Valid @RequestBody UpdatePasswordInputDTO input){
        return new JSONResult(userService.updatePassword(input));
    }
}
