package com.cqut.stack.bn.dao;


import com.cqut.stack.bn.pojo.dto.permission.PermissionDTO;
import com.cqut.stack.bn.pojo.dto.user.*;
import com.cqut.stack.bn.pojo.entity.user.User;
import com.cqut.stack.bn.pojo.entity.user.UserRole;
import com.github.pagehelper.Page;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface UserMapper {
    /**
     * 根据Account查询用户
     * @param account
     * @return
     */
    User findUserByAccount(String account);

    /**
     * 新增用户
     * @param user
     * @return
     */
    Boolean insertUser(User user);

    /**
     * 新增用户角色关系
     * @param userRole
     * @return
     */
    Boolean addUserRole(UserRole userRole);

    /**
     * 检查用户是否存在
     * @param account
     * @return
     */
    Boolean checkAccount(@Param("account") String account);

    /**
     * 获取所有的用户列表
     * @return
     */
    Page<SelectUserListDTO> selectUserList();

    /**
     * 更改用户状态
     * @param userId
     * @return
     */
    Boolean changeUserStatus(@Param("userId")String userId);

    /**
     * 更改用户的角色信息
     * @return
     */
    Boolean changeUserRole(ChangeUserRoleInputDTO data);

    /**
     * 删除用户信息
     * @param userId
     * @return
     */
    Boolean deleteUser(@Param("userId")String userId);

    /**
     * 根据用户ID获得用户详细信息
     * @param userId
     * @return
     */
    SelectByUserIdDTO selectByUserId(@Param("userId")String userId);

    /**
     * 获取角色列表
     * @return
     */
    List<SelectRoleListDTO> selectRoleList();

    /**
     * 系统用户修改密码
     * @param input
     * @return
     */
    Boolean updatePassword(UpdatePasswordInputDTO input);

    /**
     * 根据角色获取资源ID列表
     * @param account
     * @return
     */
    List<String> selectPermissionId(@Param("account")String account);

    /**
     * 根据资源ID列表获取资源列表
     * @param permissionIds
     * @return
     */
    List<PermissionDTO> selectPermissionListByUser(@Param("permissionIds")List<String> permissionIds);
}