package com.cqut.stack.bn.handler;

import com.cqut.stack.bn.exception.ToolsBusinessWarn;
import com.cqut.stack.bn.util.jsonResult.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.BindingResult;
import org.springframework.validation.FieldError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import javax.servlet.http.HttpServletRequest;

/**
 * 全局异常处理器
 */
@RestControllerAdvice
@Slf4j
public class GlobalExceptionHandler {

    /**
     * 捕获@validate参数校验异常
     */
    @ExceptionHandler(MethodArgumentNotValidException.class)
    public Result<?> MethodArgumentNotValidExceptionHandler(HttpServletRequest request, MethodArgumentNotValidException ex) {
        final BindingResult bindingResult = ex.getBindingResult();
        StringBuilder errMsg = new StringBuilder(bindingResult.getFieldErrors().size() * 16);
        for (int i = 0; i < bindingResult.getFieldErrors().size(); i++) {
            if (i > 0) {
                errMsg.append(",");
            }
            FieldError error = bindingResult.getFieldErrors().get(i);
            errMsg.append(error.getDefaultMessage());
        }
        log.error("{} 传参错误：{}", request.getRequestURI(), errMsg);
        return new Result<>(Result.OPERATION_RESULT_TYPE.failure, 500, ex.getMessage(),null);
    }

    /**
     * 自定义运行时异常
     * 此异常需由自己抛出
     */
    @ExceptionHandler(ToolsBusinessWarn.class)
    public Result<?> ExceptionHandler(HttpServletRequest request, Exception ex) {
        ToolsBusinessWarn businessWarn = (ToolsBusinessWarn) ex;
        log.error("{} 捕获异常：{}", request.getRequestURI(), ex.getMessage());
        return new Result<>(Result.OPERATION_RESULT_TYPE.failure, 500, ex.getMessage(),null);
    }
}
