package com.cqut.stack.bn.service.impl;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.cqut.stack.bn.pojo.bo.areaTransaction.GetRecentlyCategoryTradeTrendBO;
import com.cqut.stack.bn.pojo.dto.areaTransaction.AreaTransactionImportDTO;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.FourOfficeImportDTO;
import com.cqut.stack.bn.pojo.dto.resourceTrade.*;
import com.cqut.stack.bn.pojo.entity.AreaTransaction;
import com.cqut.stack.bn.dao.AreaTransactionMapper;
import com.cqut.stack.bn.pojo.entity.HotlineAcceptance;
import com.cqut.stack.bn.pojo.enums.ResourceTradeEnum;
import com.cqut.stack.bn.pojo.listener.AreaTransactionListener;
import com.cqut.stack.bn.pojo.listener.FourOfficeListener;
import com.cqut.stack.bn.pojo.vo.resourceTrade.GetCategoryTradeInfoVO;
import com.cqut.stack.bn.pojo.vo.resourceTrade.GetCategoryTradeProportionVO;
import com.cqut.stack.bn.pojo.vo.resourceTrade.GetHistoryTradeInfoVO;
import com.cqut.stack.bn.pojo.vo.resourceTrade.GetRecentlyCategoryTradeTrendVO;
import com.cqut.stack.bn.service.AreaTransactionService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class AreaTransactionServiceImpl extends ServiceImpl<AreaTransactionMapper, AreaTransaction> implements AreaTransactionService {

    @Resource
    AreaTransactionMapper areaTransactionMapper;

    @Override
    public GetHistoryTradeInfoVO getHistoryTradeInfo(GetHistoryTradeInfoDTO dto) {
        return areaTransactionMapper.getHistoryTradeInfo(dto);
    }

    @Override
    public List<GetCategoryTradeInfoVO> getCategoryTradeInfo(GetCategoryTradeInfoDTO dto) {
        return areaTransactionMapper.getCategoryTradeInfo(dto);
    }

    @Override
    public GetCategoryTradeProportionVO getCategoryTradeProportion(GetCategoryTradeProportionDTO dto) {
        GetCategoryTradeInfoDTO getCategoryTradeInfoDTO = new GetCategoryTradeInfoDTO();
        getCategoryTradeInfoDTO.setYear(dto.getYear());
        List<GetCategoryTradeInfoVO> categoryTradeInfoVOList = areaTransactionMapper.getCategoryTradeInfo(getCategoryTradeInfoDTO);
        List<Integer> xAxis = categoryTradeInfoVOList.stream().map(GetCategoryTradeInfoVO::getTransactionType).collect(Collectors.toList());
        List<String> xAxisData = new ArrayList<>();
        xAxis.forEach(districtName -> xAxisData.add(ResourceTradeEnum.TradeTypeEnum.getNameByCode(districtName)));
        List<Double> yAxis = categoryTradeInfoVOList.stream().map(GetCategoryTradeInfoVO::getTransactionAmount).collect(Collectors.toList());
        double transactionAmount = yAxis.stream().mapToDouble(Double::doubleValue).sum();
        List<Integer> yAxis2 = categoryTradeInfoVOList.stream().map(GetCategoryTradeInfoVO::getTransactionCount).collect(Collectors.toList());
        int transactionCount = yAxis2.stream().mapToInt(Integer::intValue).sum();
        List<String> yAxisData = new ArrayList<>();
        List<String> yAxisData2 = new ArrayList<>();
        categoryTradeInfoVOList.forEach(getCategoryTradeInfoVO -> {
            yAxisData.add(String.format("%.2f", (double) getCategoryTradeInfoVO.getTransactionCount() / transactionCount * 100) + "%");
            yAxisData2.add(String.format("%.2f", getCategoryTradeInfoVO.getTransactionAmount() / transactionAmount * 100) + "%");
        });
        GetCategoryTradeProportionVO getCategoryTradeProportionVO = new GetCategoryTradeProportionVO();
        getCategoryTradeProportionVO.setXAxisData(xAxisData);
        getCategoryTradeProportionVO.setYAxisData(yAxisData);
        getCategoryTradeProportionVO.setYAxisData2(yAxisData2);
        return getCategoryTradeProportionVO;
    }

    @Override
    public GetRecentlyCategoryTradeTrendVO getRecentlyCategoryTradeTrend(GetRecentlyCategoryTradeTrendDTO dto) {
        LocalDate startDate = LocalDate.of(dto.getYear(), 1, 1);
        // 获取当前日期
        // 创建一个列表来存储过去12个月的日期
        Map<String, Integer> map = new LinkedHashMap<>();
        Map<String, Double> map2 = new LinkedHashMap<>();
        // 定义日期格式
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM");
        // 循环获取过去12个月的日期
        for (int i = 0; i <= 11; i++) {
            LocalDate currentMonth = startDate.plusMonths(i);
            String formattedDate = currentMonth.format(formatter);
            map.put(formattedDate, 0);
            map2.put(formattedDate, 0D);
        }
        List<GetRecentlyCategoryTradeTrendBO> getRecentlyCategoryTradeTrendBOList = areaTransactionMapper.getRecentlyCategoryTradeTrend(startDate, startDate.plusMonths(11));
        getRecentlyCategoryTradeTrendBOList.forEach(
                getRecentlyCategoryTradeTrendBO -> {
                    map.put(getRecentlyCategoryTradeTrendBO.getMonth(), getRecentlyCategoryTradeTrendBO.getTransactionCount());
                    map2.put(getRecentlyCategoryTradeTrendBO.getMonth(), getRecentlyCategoryTradeTrendBO.getTransactionAmount());
                }
        );
        List<String> xAxisData = new ArrayList<>(map.keySet());
        List<Integer> yAxisData = new ArrayList<>(map.values());
        List<Double> yAxisData2 = new ArrayList<>(map2.values());
        GetRecentlyCategoryTradeTrendVO getRecentlyAcceptCountTrendVO = new GetRecentlyCategoryTradeTrendVO();
        getRecentlyAcceptCountTrendVO.setXAxisData(xAxisData);
        getRecentlyAcceptCountTrendVO.setYAxisData(yAxisData);
        getRecentlyAcceptCountTrendVO.setYAxisData2(yAxisData2);
        return getRecentlyAcceptCountTrendVO;
    }

    @Override
    public List<AreaTransaction> getAreaTransactionList(GetAreaTransactionDTO dto) {
        LambdaQueryWrapper<AreaTransaction> qw = new LambdaQueryWrapper<>();
        qw.ge(ObjectUtil.isNotEmpty(dto.getStartDate()), AreaTransaction::getStatDate, dto.getStartDate())
                .le(ObjectUtil.isNotEmpty(dto.getEndDate()), AreaTransaction::getStatDate, dto.getEndDate());
        PageHelper.startPage(dto.getPageNum(), dto.getPageSize());
        return this.list(qw);
    }

    @Override
    public void importResourceTransactionInfo(ExcelImportDTO dto) {
        // 删除所有旧数据
        areaTransactionMapper.deleteAll();
        AreaTransactionListener areaTransactionListener = new AreaTransactionListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), AreaTransactionImportDTO.class, areaTransactionListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(areaTransactionListener.getAreaTransactionList());
    }

    @Override
    public AreaTransaction getCurrentAreaTradeInfo(GetCurrentAreaTradeInfoDTO dto) {
        LambdaQueryWrapper<AreaTransaction> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.like(AreaTransaction::getStatDate,dto.getYear())
                .eq(AreaTransaction::getAreaName,dto.getAreaName());
        List<AreaTransaction> list = this.list(queryWrapper);
        double transactionAmount = 0;
        double saveAmount = 0;
        int transactionCount = 0;
        for (AreaTransaction areaTransaction : list) {
            transactionAmount = transactionAmount + areaTransaction.getTransactionAmount();
            saveAmount = saveAmount + areaTransaction.getSaveAmount();
            transactionCount = transactionCount + areaTransaction.getTransactionCount();
        }
        AreaTransaction areaTransaction = new AreaTransaction();
        areaTransaction.setTransactionAmount(transactionAmount);
        areaTransaction.setSaveAmount(saveAmount);
        areaTransaction.setTransactionCount(transactionCount);
        return areaTransaction;
    }
}
