package com.cqut.stack.bn.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cqut.stack.bn.dao.CharacteristicThingMapper;
import com.cqut.stack.bn.pojo.dto.characteristicThing.CharacteristicThingImportDTO;
import com.cqut.stack.bn.pojo.dto.characteristicThing.GetCharacteristicThingInfoDTO;
import com.cqut.stack.bn.pojo.dto.characteristicThing.GetCharacteristicThingInfoListByPageDTO;
import com.cqut.stack.bn.pojo.dto.characteristicThing.ImportCharacteristicThingDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.FourOfficeImportDTO;
import com.cqut.stack.bn.pojo.entity.CharacteristicThing;
import com.cqut.stack.bn.pojo.entity.EfficientThing;
import com.cqut.stack.bn.pojo.enums.GovernmentServiceEnum;
import com.cqut.stack.bn.pojo.listener.CharacteristicThingListener;
import com.cqut.stack.bn.pojo.listener.FourOfficeListener;
import com.cqut.stack.bn.pojo.vo.characteristicThing.GetCharacteristicThingInfoVO;
import com.cqut.stack.bn.pojo.vo.efficientThing.GetEfficientThingInfoVO;
import com.cqut.stack.bn.service.CharacteristicThingService;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.*;


@Service
public class CharacteristicThingServiceImpl extends ServiceImpl<CharacteristicThingMapper, CharacteristicThing> implements CharacteristicThingService {
    @Resource
    private CharacteristicThingMapper characteristicThingMapper;

    @Override
    public List<CharacteristicThing> getCharacteristicThingInfoListByPage(GetCharacteristicThingInfoListByPageDTO dto) {
        LambdaQueryWrapper<CharacteristicThing> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.ge(Objects.nonNull(dto.getBeginDate()), CharacteristicThing::getStatDate, dto.getBeginDate())
                .le(Objects.nonNull(dto.getEndDate()), CharacteristicThing::getStatDate, dto.getEndDate());
        PageHelper.startPage(dto.getPageNum(), dto.getPageSize());
        return characteristicThingMapper.selectList(queryWrapper);
    }

    @Override
    public GetCharacteristicThingInfoVO getCharacteristicThingInfo(GetCharacteristicThingInfoDTO dto) {
        LambdaQueryWrapper<CharacteristicThing> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.like(ObjectUtil.isNotEmpty(dto.getYear()),CharacteristicThing::getStatDate,dto.getYear());
        List<CharacteristicThing> characteristicThingList = this.list(queryWrapper);

        List<String> xAxisData = new ArrayList<>();
        List<Integer> applyCount = new ArrayList<>();
        List<Integer> processCount = new ArrayList<>();
        List<Integer> completeCount = new ArrayList<>();
        for (CharacteristicThing characteristicThing : characteristicThingList) {
            xAxisData.add(GovernmentServiceEnum.DistrictEnum.getNameByCode(characteristicThing.getDistrictName()));
            applyCount.add(characteristicThing.getApplyCount());
            processCount.add(characteristicThing.getProcessCount());
            completeCount.add(characteristicThing.getCompleteCount());
        }
        GetCharacteristicThingInfoVO getCharacteristicThingInfoVO = new GetCharacteristicThingInfoVO();
        Map<String,List<Integer>> yAxisData = new HashMap<>();
        yAxisData.put("申请件数",applyCount);
        yAxisData.put("受理件数",processCount);
        yAxisData.put("办结件数",completeCount);
        getCharacteristicThingInfoVO.setXAxisData(xAxisData);
        getCharacteristicThingInfoVO.setYAxisData(yAxisData);
        return getCharacteristicThingInfoVO;
    }

    @Override
    public void importCharacteristicThing(ImportCharacteristicThingDTO dto) {
        // 删除所有旧数据
        characteristicThingMapper.deleteAll();
        CharacteristicThingListener characteristicThingListener = new CharacteristicThingListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), CharacteristicThingImportDTO.class, characteristicThingListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(characteristicThingListener.getCharacteristicThingList());
    }
}
