package com.cqut.stack.bn.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.pojo.dto.areaHandle.ImportAreaHandleInfoDTO;
import com.cqut.stack.bn.pojo.dto.efficientThing.EfficientThingImportDTO;
import com.cqut.stack.bn.pojo.dto.efficientThing.GetEfficientThingInfoDTO;
import com.cqut.stack.bn.pojo.dto.efficientThing.GetEfficientThingInfoListByPageDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.FourOfficeImportDTO;
import com.cqut.stack.bn.pojo.entity.EfficientThing;
import com.cqut.stack.bn.dao.EfficientThingMapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cqut.stack.bn.pojo.enums.GovernmentServiceEnum;
import com.cqut.stack.bn.pojo.listener.EfficientThingListener;
import com.cqut.stack.bn.pojo.listener.FourOfficeListener;
import com.cqut.stack.bn.pojo.vo.efficientThing.GetEfficientThingInfoVO;
import com.cqut.stack.bn.service.EfficientThingService;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;


@Service
public class EfficientThingServiceImpl extends ServiceImpl<EfficientThingMapper, EfficientThing> implements EfficientThingService {
    @Resource
    private EfficientThingMapper efficientThingMapper;

    @Override
    public List<EfficientThing> getEfficientThingInfoListByPage(GetEfficientThingInfoListByPageDTO dto) {
        LambdaQueryWrapper<EfficientThing> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.ge(Objects.nonNull(dto.getBeginDate()), EfficientThing::getStatDate, dto.getBeginDate())
                .le(Objects.nonNull(dto.getEndDate()), EfficientThing::getStatDate, dto.getEndDate());
        PageHelper.startPage(dto.getPageNum(), dto.getPageSize());
        return efficientThingMapper.selectList(queryWrapper);
    }

    @Override
    public GetEfficientThingInfoVO getEfficientThingInfo(GetEfficientThingInfoDTO dto) {
        LambdaQueryWrapper<EfficientThing> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.like(ObjectUtil.isNotEmpty(dto.getYear()),EfficientThing::getStatDate,dto.getYear());
        List<EfficientThing> efficientThingList = this.list(queryWrapper);

        List<String> xAxisData = new ArrayList<>();
        List<Integer> applyCount = new ArrayList<>();
        List<Integer> processCount = new ArrayList<>();
        List<Integer> completeCount = new ArrayList<>();
        for (EfficientThing efficientThing : efficientThingList) {
            xAxisData.add(GovernmentServiceEnum.DistrictEnum.getNameByCode(efficientThing.getDistrictName()));
            applyCount.add(efficientThing.getApplyCount());
            processCount.add(efficientThing.getProcessCount());
            completeCount.add(efficientThing.getCompleteCount());
        }
        GetEfficientThingInfoVO getEfficientThingInfoVO = new GetEfficientThingInfoVO();
        Map<String,List<Integer>> yAxisData = new HashMap<>();
        yAxisData.put("申请件数",applyCount);
        yAxisData.put("受理件数",processCount);
        yAxisData.put("办结件数",completeCount);
        getEfficientThingInfoVO.setXAxisData(xAxisData);
        getEfficientThingInfoVO.setYAxisData(yAxisData);
        return getEfficientThingInfoVO;
    }

    @Override
    public void importEfficientThingInfo(ImportAreaHandleInfoDTO dto) {
        // 删除所有旧数据
        efficientThingMapper.deleteAll();
        EfficientThingListener efficientThingListener = new EfficientThingListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), EfficientThingImportDTO.class, efficientThingListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(efficientThingListener.getEfficientThingList());
    }
}
