package com.cqut.stack.bn.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cqut.stack.bn.dao.ElectronicCertificateMapper;
import com.cqut.stack.bn.pojo.dto.electronicCertificate.ElectronicCertificateImportDTO;
import com.cqut.stack.bn.pojo.dto.electronicCertificate.GetElectronicCertificateInfoDTO;
import com.cqut.stack.bn.pojo.dto.electronicCertificate.GetElectronicCertificateInfoListByPageDTO;
import com.cqut.stack.bn.pojo.dto.electronicCertificate.ImportElectronicCertificateInfoDTO;
import com.cqut.stack.bn.pojo.entity.ElectronicCertificate;
import com.cqut.stack.bn.pojo.listener.ElectronicCertificateListener;
import com.cqut.stack.bn.pojo.vo.electronicCertificate.GetElectronicCertificateInfoVO;
import com.cqut.stack.bn.service.ElectronicCertificateService;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

@Service
public class ElectronicCertificateServiceImpl extends ServiceImpl<ElectronicCertificateMapper, ElectronicCertificate> implements ElectronicCertificateService {

    @Resource
    private ElectronicCertificateMapper electronicCertificateMapper;

    @Override
    public GetElectronicCertificateInfoVO getElectronicCertificateInfo(GetElectronicCertificateInfoDTO dto) {
        ElectronicCertificate electronicCertificate = electronicCertificateMapper.getElectronicCertificateInfo(dto);
        if(ObjectUtil.isEmpty(electronicCertificate))
            return null;
        List<String> xAxisData = new ArrayList<>();
        xAxisData.add("需产生证照的办件数");
        xAxisData.add("产生证照的办件数");
        xAxisData.add("未产生证照的办件数");
        List<Integer> yAxisData = new ArrayList<>();
        yAxisData.add(electronicCertificate.getNeedCertificateCount());
        yAxisData.add(electronicCertificate.getCreateCertificateCount());
        yAxisData.add(electronicCertificate.getUncreateCertificateCount());
        GetElectronicCertificateInfoVO getElectronicCertificateInfoVO = new GetElectronicCertificateInfoVO();
        getElectronicCertificateInfoVO.setYAxisData(yAxisData);
        getElectronicCertificateInfoVO.setXAxisData(xAxisData);
        return getElectronicCertificateInfoVO;
    }

    @Override
    public List<ElectronicCertificate> getElectronicCertificateInfoListByPage(GetElectronicCertificateInfoListByPageDTO dto) {
        LambdaQueryWrapper<ElectronicCertificate> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.ge(Objects.nonNull(dto.getBeginDate()), ElectronicCertificate::getStatDate, dto.getBeginDate())
                .le(Objects.nonNull(dto.getEndDate()), ElectronicCertificate::getStatDate, dto.getEndDate());
        PageHelper.startPage(dto.getPageNum(), dto.getPageSize());
        return electronicCertificateMapper.selectList(queryWrapper);
    }

    @Override
    public void importElectronicCertificateInfo(ImportElectronicCertificateInfoDTO dto) {
        // 删除所有旧数据
        electronicCertificateMapper.deleteAll();
        ElectronicCertificateListener electronicCertificateListener = new ElectronicCertificateListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), ElectronicCertificateImportDTO.class, electronicCertificateListener).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(electronicCertificateListener.getElectronicCertificateList());
    }
}
