package com.cqut.stack.bn.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.dao.ElectronicSealMapper;
import com.cqut.stack.bn.pojo.dto.electronicSeal.ElectronicSealInfoImportDTO;
import com.cqut.stack.bn.pojo.dto.electronicSeal.GetElectronicSealInfoDTO;
import com.cqut.stack.bn.pojo.dto.electronicSeal.GetElectronicSealInfoListDTOByPageDTO;
import com.cqut.stack.bn.pojo.dto.electronicSeal.ImportElectronicSealInfoDTO;
import com.cqut.stack.bn.pojo.entity.ElectronicSeal;
import com.cqut.stack.bn.pojo.listener.ElectronicSealListener;
import com.cqut.stack.bn.pojo.vo.electronicSeal.GetElectronicSealInfoVO;
import com.cqut.stack.bn.service.ElectronicSealService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;
import java.util.Objects;

@Service
public class ElectronicSealServiceImpl extends ServiceImpl<ElectronicSealMapper, ElectronicSeal> implements ElectronicSealService {

    @Resource
    private ElectronicSealMapper electronicSealMapper;
    @Override
    public GetElectronicSealInfoVO getElectronicSealInfo(GetElectronicSealInfoDTO dto) {
        GetElectronicSealInfoVO getElectronicSealInfoVO = electronicSealMapper.getElectronicSealInfo(dto);
        if(ObjectUtil.isEmpty(getElectronicSealInfoVO))
            return null;
        GetElectronicSealInfoVO total = electronicSealMapper.getElectronicSealTotalInfo(dto);
        getElectronicSealInfoVO.setSealMakeTotalCount(total.getSealMakeTotalCount());
        getElectronicSealInfoVO.setSealApplyTotalCount(total.getSealApplyTotalCount());
        getElectronicSealInfoVO.setUsedSealTotalCount(total.getUsedSealTotalCount());
        getElectronicSealInfoVO.setNoSealDeptTotalCount(total.getNoSealDeptTotalCount());
        getElectronicSealInfoVO.setMakeSealDeptTotalCount(total.getMakeSealDeptTotalCount());
        return getElectronicSealInfoVO;
    }

    @Override
    public List<ElectronicSeal> getElectronicSealInfoListByPage(GetElectronicSealInfoListDTOByPageDTO dto) {
        LambdaQueryWrapper<ElectronicSeal> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.ge(Objects.nonNull(dto.getBeginDate()), ElectronicSeal::getStatDate, dto.getBeginDate())
                .le(Objects.nonNull(dto.getEndDate()), ElectronicSeal::getStatDate, dto.getEndDate());
        PageHelper.startPage(dto.getPageNum(), dto.getPageSize());
        return electronicSealMapper.selectList(queryWrapper);
    }

    @Override
    public void importElectronicSealInfo(ImportElectronicSealInfoDTO dto) {
        // 删除所有旧数据
        electronicSealMapper.deleteAll();
        ElectronicSealListener electronicSealListener = new ElectronicSealListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), ElectronicSealInfoImportDTO.class, electronicSealListener).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(electronicSealListener.getElectronicSealList());
    }
}
