package com.cqut.stack.bn.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.pojo.dto.electronicSeal.ElectronicSealInfoImportDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.FourOfficeImportDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.GetFourOfficeInfoDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.GetFourOfficeInfoListByPageDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.ImportFourOfficeInfoDTO;
import com.cqut.stack.bn.pojo.entity.CharacteristicThing;
import com.cqut.stack.bn.pojo.entity.EfficientThing;
import com.cqut.stack.bn.pojo.entity.ElectronicSeal;
import com.cqut.stack.bn.pojo.entity.FourOfficeInfo;
import com.cqut.stack.bn.dao.FourOfficeInfoMapper;
import com.cqut.stack.bn.pojo.listener.ElectronicSealListener;
import com.cqut.stack.bn.pojo.listener.FourOfficeListener;
import com.cqut.stack.bn.service.FourOfficeInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;
import java.util.Objects;


@Service
public class FourOfficeInfoServiceImpl extends ServiceImpl<FourOfficeInfoMapper, FourOfficeInfo> implements FourOfficeInfoService {

    @Resource
    private FourOfficeInfoMapper fourOfficeInfoMapper;

    @Override
    public List<FourOfficeInfo> getFourOfficeInfoListByPage(GetFourOfficeInfoListByPageDTO dto) {
        LambdaQueryWrapper<FourOfficeInfo> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.ge(Objects.nonNull(dto.getBeginDate()), FourOfficeInfo::getStatDate, dto.getBeginDate())
                .le(Objects.nonNull(dto.getEndDate()), FourOfficeInfo::getStatDate, dto.getEndDate());
        PageHelper.startPage(dto.getPageNum(), dto.getPageSize());
        return fourOfficeInfoMapper.selectList(queryWrapper);
    }

    @Override
    public List<FourOfficeInfo> getFourOfficeInfo(GetFourOfficeInfoDTO dto) {
        LambdaQueryWrapper<FourOfficeInfo> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(FourOfficeInfo::getDistrictName,dto.getAreaName())
                .like(ObjectUtil.isNotEmpty(dto.getYear()),FourOfficeInfo::getStatDate,dto.getYear());
        return this.list(queryWrapper);
    }

    @Override
    public void importFourOfficeInfo(ImportFourOfficeInfoDTO dto) {
        // 删除所有旧数据
        fourOfficeInfoMapper.deleteAll();
        FourOfficeListener fourOfficeListener = new FourOfficeListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), FourOfficeImportDTO.class, fourOfficeListener)
                    .headRowNumber(2).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(fourOfficeListener.getFourOfficeInfoList());
    }
}
