package com.cqut.stack.bn.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.districtHandle.DistrictHandleImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineAcceptance.GetCurrentAreaHotlineAcceptanceDTO;
import com.cqut.stack.bn.pojo.dto.hotlineAcceptance.HotlineAcceptanceImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDeptAcceptance.GetHotlineDeptAcceptanceDTO;
import com.cqut.stack.bn.pojo.entity.HotlineAcceptance;
import com.cqut.stack.bn.dao.HotlineAcceptanceMapper;
import com.cqut.stack.bn.pojo.listener.DistrictHandleListener;
import com.cqut.stack.bn.pojo.listener.HotlineAcceptanceListener;
import com.cqut.stack.bn.service.HotlineAcceptanceService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;

@Service
public class HotlineAcceptanceServiceImpl extends ServiceImpl<HotlineAcceptanceMapper, HotlineAcceptance> implements HotlineAcceptanceService {

    @Resource
    private HotlineAcceptanceMapper hotlineAcceptanceMapper;

    @Override
    public List<HotlineAcceptance> getCurrentAreaHotlineAcceptance(GetCurrentAreaHotlineAcceptanceDTO dto) {
        LambdaQueryWrapper<HotlineAcceptance> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(ObjectUtil.isNotEmpty(dto.getYear()),HotlineAcceptance::getStatDate,dto.getYear());
        List<HotlineAcceptance> list = this.list(queryWrapper);
        return list;
    }

    @Override
    public List<HotlineAcceptance> getHotlineAcceptance(GetHotlineDeptAcceptanceDTO getHotlineDeptAcceptanceDTO) {
        LambdaQueryWrapper<HotlineAcceptance> queryWrapper = new LambdaQueryWrapper<>();
        if(getHotlineDeptAcceptanceDTO.getStartYear() != null)
            queryWrapper.ge(HotlineAcceptance::getStatDate,getHotlineDeptAcceptanceDTO.getStartYear());
        if(getHotlineDeptAcceptanceDTO.getEndYear() != null)
            queryWrapper.le(HotlineAcceptance::getStatDate,getHotlineDeptAcceptanceDTO.getEndYear());
        PageHelper.startPage(getHotlineDeptAcceptanceDTO.getPageNum(),getHotlineDeptAcceptanceDTO.getPageSize());
        return this.list(queryWrapper);
    }

    @Override
    public void importHotlineAcceptance(ExcelImportDTO dto) {
        // 删除所有旧数据
        hotlineAcceptanceMapper.deleteAll();
        HotlineAcceptanceListener hotlineAcceptanceListener = new HotlineAcceptanceListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), HotlineAcceptanceImportDTO.class, hotlineAcceptanceListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(hotlineAcceptanceListener.getHotlineAcceptanceList());
    }
}
