package com.cqut.stack.bn.service.impl;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cqut.stack.bn.dao.HotlineDailyAcceptanceMapper;
import com.cqut.stack.bn.pojo.bo.hotlineDailyAcceptance.GetRecentlyAcceptCountTrendBO;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.districtHandle.DistrictHandleImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDailyAcceptance.DateDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDailyAcceptance.HotlineDailyAcceptanceImportDTO;
import com.cqut.stack.bn.pojo.entity.HotlineDailyAcceptance;
import com.cqut.stack.bn.pojo.listener.DistrictHandleListener;
import com.cqut.stack.bn.pojo.listener.HotlineDailyAcceptanceListener;
import com.cqut.stack.bn.pojo.vo.hotlineDailyAcceptance.GetRecentlyAcceptCountTrendVO;
import com.cqut.stack.bn.pojo.vo.hotlineDailyAcceptance.GetHistoryAcceptCountVO;
import com.cqut.stack.bn.service.HotlineDailyAcceptanceService;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;

@Service
public class HotlineDailyAcceptanceServiceImpl extends ServiceImpl<HotlineDailyAcceptanceMapper, HotlineDailyAcceptance> implements HotlineDailyAcceptanceService {
    @Resource
    private HotlineDailyAcceptanceMapper hotlineDailyAcceptanceMapper;

    @Override
    public GetHistoryAcceptCountVO getHistoryAcceptCount() {
        // 获取当前日期
        LocalDate currentDate = LocalDate.now();
        // 获取当前年份
        int year = currentDate.getYear();
        // 获取当前月份
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM");
        String month = currentDate.format(formatter);
        // 获取当年、当月、历史接件量
        GetHistoryAcceptCountVO getHistoryAcceptCountVO = new GetHistoryAcceptCountVO();
        getHistoryAcceptCountVO.setCurrentYearCount(hotlineDailyAcceptanceMapper.getHistoryAcceptCount(Integer.toString(year),null));
        getHistoryAcceptCountVO.setCurrentMonthCount(hotlineDailyAcceptanceMapper.getHistoryAcceptCount(null,month));
        getHistoryAcceptCountVO.setHistoryCount(hotlineDailyAcceptanceMapper.getHistoryAcceptCount(null,null));
        return getHistoryAcceptCountVO;
    }

    @Override
    public GetRecentlyAcceptCountTrendVO getRecentlyAcceptCountTrend() {
        // 获取当前日期
        LocalDate startDate = LocalDate.of(LocalDate.now().getYear(), 1, 1);
        // 创建一个列表来存储过去12个月的日期
        Map<String,Integer> map = new LinkedHashMap<>();
        // 定义日期格式
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM");
        // 循环获取过去12个月的日期
        for (int i = 0; i <= 11; i++) {
            LocalDate currentMonth = startDate.plusMonths(i);
            String formattedDate = currentMonth.format(formatter);
            map.put(formattedDate,0);
        }
        GetRecentlyAcceptCountTrendVO getRecentlyAcceptCountTrendVO = new GetRecentlyAcceptCountTrendVO();
        List<GetRecentlyAcceptCountTrendBO> getRecentlyAcceptCountTrendBOList =
                hotlineDailyAcceptanceMapper.getRecentlyAcceptCountTrend(startDate,startDate.plusMonths(11));
        getRecentlyAcceptCountTrendBOList.forEach(
                getRecentlyAcceptCountTrendBO -> map.put(getRecentlyAcceptCountTrendBO.getMonth(), getRecentlyAcceptCountTrendBO.getCount())
        );
        List<String> xAxisData = new ArrayList<>(map.keySet());
        List<Integer> yAxisData = new ArrayList<>(map.values());
        getRecentlyAcceptCountTrendVO.setXAxisData(xAxisData);
        getRecentlyAcceptCountTrendVO.setYAxisData(yAxisData);
        return getRecentlyAcceptCountTrendVO;
    }

    @Override
    public List<HotlineDailyAcceptance> getHotlineDailyAcceptance(DateDTO dateDTO) {
        LambdaQueryWrapper<HotlineDailyAcceptance> queryWrapper = new LambdaQueryWrapper<>();
        if(dateDTO.getStartDate()!=null)
            queryWrapper.ge(HotlineDailyAcceptance::getAcceptDate,dateDTO.getStartDate());
        if(dateDTO.getEndDate()!=null)
            queryWrapper.le(HotlineDailyAcceptance::getAcceptDate,dateDTO.getEndDate());
        PageHelper.startPage(dateDTO.getPageNum(),dateDTO.getPageSize());
        return hotlineDailyAcceptanceMapper.selectList(queryWrapper);
    }

    @Override
    public void importHotlineDailyAcceptance(ExcelImportDTO dto) {
        // 删除所有旧数据
        hotlineDailyAcceptanceMapper.deleteAll();
        HotlineDailyAcceptanceListener hotlineDailyAcceptanceListener = new HotlineDailyAcceptanceListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), HotlineDailyAcceptanceImportDTO.class, hotlineDailyAcceptanceListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(hotlineDailyAcceptanceListener.getHotlineDailyAcceptanceList());
    }
}
