package com.cqut.stack.bn.service.impl;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cqut.stack.bn.dao.HotlineDeptAcceptanceMapper;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.districtHandle.DistrictHandleImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDeptAcceptance.GetHotlineDeptAcceptanceDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDeptAcceptance.HotlineDeptAcceptanceImportDTO;
import com.cqut.stack.bn.pojo.entity.HotlineDeptAcceptance;
import com.cqut.stack.bn.pojo.dto.hotlineDeptAcceptance.GetMunicipalDeptAcceptInfoDTO;
import com.cqut.stack.bn.pojo.enums.Hotline12345Enum;
import com.cqut.stack.bn.pojo.listener.DistrictHandleListener;
import com.cqut.stack.bn.pojo.listener.HotlineDeptAcceptanceListener;
import com.cqut.stack.bn.pojo.vo.hotlineDeptAcceptance.GetMunicipalDeptAcceptInfoVO;
import com.cqut.stack.bn.service.HotlineDeptAcceptanceService;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class HotlineDeptAcceptanceServiceImpl extends ServiceImpl<HotlineDeptAcceptanceMapper, HotlineDeptAcceptance> implements HotlineDeptAcceptanceService {
    @Resource
    private HotlineDeptAcceptanceMapper hotlineDeptAcceptanceMapper;

    @Override
    public GetMunicipalDeptAcceptInfoVO getMunicipalDeptAcceptInfo(GetMunicipalDeptAcceptInfoDTO dto) {
        List<HotlineDeptAcceptance> data = new ArrayList<>();
        if(dto.getAnalyseType() == 0)
            data =  hotlineDeptAcceptanceMapper.getMunicipalDeptAcceptInfo(dto);
        if(dto.getAnalyseType() == 1)
            data =  hotlineDeptAcceptanceMapper.getMunicipalDeptAcceptInfo2(dto);

        List<String> xAxisData = data.stream().map(HotlineDeptAcceptance::getDeptName).collect(Collectors.toList());
        Map<String,List<Integer>> yAxisData = new LinkedHashMap<>();
        List<Integer> completeList = data.stream().map(HotlineDeptAcceptance::getCompleteCount).collect(Collectors.toList());
        List<Integer> pendingList = data.stream().map(HotlineDeptAcceptance::getPendingCount).collect(Collectors.toList());
        List<Integer> overdueList = data.stream().map(HotlineDeptAcceptance::getOverdueCount).collect(Collectors.toList());
        yAxisData.put("已办",completeList);
        yAxisData.put("待办",pendingList);
        yAxisData.put("超期",overdueList);
        GetMunicipalDeptAcceptInfoVO getMunicipalDeptAcceptInfoVO = new GetMunicipalDeptAcceptInfoVO();
        getMunicipalDeptAcceptInfoVO.setXAxisData(xAxisData);
        getMunicipalDeptAcceptInfoVO.setYAxisData(yAxisData);
        return getMunicipalDeptAcceptInfoVO;
    }

    @Override
    public List<HotlineDeptAcceptance> getHotlineDeptAcceptance(GetHotlineDeptAcceptanceDTO getHotlineDeptAcceptanceDTO) {
        LambdaQueryWrapper<HotlineDeptAcceptance> queryWrapper = new LambdaQueryWrapper<>();
        if(getHotlineDeptAcceptanceDTO.getStartYear() != null)
            queryWrapper.ge(HotlineDeptAcceptance::getStatDate,getHotlineDeptAcceptanceDTO.getStartYear());
        if(getHotlineDeptAcceptanceDTO.getEndYear() != null)
            queryWrapper.le(HotlineDeptAcceptance::getStatDate,getHotlineDeptAcceptanceDTO.getEndYear());
        PageHelper.startPage(getHotlineDeptAcceptanceDTO.getPageNum(),getHotlineDeptAcceptanceDTO.getPageSize());
        return hotlineDeptAcceptanceMapper.selectList(queryWrapper);
    }

    @Override
    public void importHotlineDeptAcceptance(ExcelImportDTO dto) {
        // 删除所有旧数据
        hotlineDeptAcceptanceMapper.deleteAll();
        HotlineDeptAcceptanceListener hotlineDeptAcceptanceListener = new HotlineDeptAcceptanceListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), HotlineDeptAcceptanceImportDTO.class, hotlineDeptAcceptanceListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(hotlineDeptAcceptanceListener.getHotlineDeptAcceptanceList());
    }
}
