package com.cqut.stack.bn.service.impl;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.districtHandle.DistrictHandleImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDeptAcceptance.GetHotlineDeptAcceptanceDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDistrictAcceptance.GetHotlineDistrictAcceptInfoDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDistrictAcceptance.HotlineDistrictAcceptanceImportDTO;
import com.cqut.stack.bn.pojo.entity.HotlineDistrictAcceptance;
import com.cqut.stack.bn.dao.HotlineDistrictAcceptanceMapper;
import com.cqut.stack.bn.pojo.enums.Hotline12345Enum;
import com.cqut.stack.bn.pojo.listener.DistrictHandleListener;
import com.cqut.stack.bn.pojo.listener.HotlineDistrictAcceptanceListener;
import com.cqut.stack.bn.pojo.vo.hotlineDistrictAcceptance.GetHotlineDistrictAcceptInfoVO;
import com.cqut.stack.bn.service.HotlineDistrictAcceptanceService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class HotlineDistrictAcceptanceServiceImpl extends ServiceImpl<HotlineDistrictAcceptanceMapper, HotlineDistrictAcceptance> implements HotlineDistrictAcceptanceService {

    @Resource
    private HotlineDistrictAcceptanceMapper hotlineDistrictAcceptanceMapper;

    @Override
    public GetHotlineDistrictAcceptInfoVO getHotlineDistrictAcceptInfo(GetHotlineDistrictAcceptInfoDTO dto) {
        List<HotlineDistrictAcceptance> data = hotlineDistrictAcceptanceMapper.getHotlineDistrictAcceptInfo(dto);
        Set<Integer> xAxis = data.stream().map(HotlineDistrictAcceptance::getDistrictName).collect(Collectors.toSet());
        Set<String> xAxisData = new HashSet<>();
        xAxis.forEach(districtName -> xAxisData.add(Hotline12345Enum.DistrictEnum.getNameByCode(districtName)));
        Map<String,List<Integer>> yAxisData = new LinkedHashMap<>();
        Map<Integer,List<HotlineDistrictAcceptance>> hotlineDistrictAcceptanceMap = data.stream().collect(Collectors.groupingBy(HotlineDistrictAcceptance::getAcceptStatus));
        for(Map.Entry<Integer,List<HotlineDistrictAcceptance>> map : hotlineDistrictAcceptanceMap.entrySet()){
            yAxisData.put(
                    Hotline12345Enum.AcceptStatEnum.getNameByCode(map.getKey()),
                    map.getValue().stream().map(HotlineDistrictAcceptance::getAcceptCount).collect(Collectors.toList())
            );
        }
        GetHotlineDistrictAcceptInfoVO getHotlineDistrictAcceptInfoVO = new GetHotlineDistrictAcceptInfoVO();
        getHotlineDistrictAcceptInfoVO.setXAxisData(xAxisData);
        getHotlineDistrictAcceptInfoVO.setYAxisData(yAxisData);
        return getHotlineDistrictAcceptInfoVO;
    }

    @Override
    public List<HotlineDistrictAcceptance> getHotlineDistrictAcceptance(GetHotlineDeptAcceptanceDTO getHotlineDeptAcceptanceDTO) {
        LambdaQueryWrapper<HotlineDistrictAcceptance> queryWrapper = new LambdaQueryWrapper<>();
        if(getHotlineDeptAcceptanceDTO.getStartYear() != null)
            queryWrapper.ge(HotlineDistrictAcceptance::getStatDate,getHotlineDeptAcceptanceDTO.getStartYear());
        if(getHotlineDeptAcceptanceDTO.getEndYear() != null)
            queryWrapper.le(HotlineDistrictAcceptance::getStatDate,getHotlineDeptAcceptanceDTO.getEndYear());
        PageHelper.startPage(getHotlineDeptAcceptanceDTO.getPageNum(),getHotlineDeptAcceptanceDTO.getPageSize());
        return hotlineDistrictAcceptanceMapper.selectList(queryWrapper);
    }

    @Override
    public void importHotlineDistrictAcceptance(ExcelImportDTO dto) {
        // 删除所有旧数据
        hotlineDistrictAcceptanceMapper.deleteAll();
        HotlineDistrictAcceptanceListener hotlineDistrictAcceptanceListener = new HotlineDistrictAcceptanceListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), HotlineDistrictAcceptanceImportDTO.class, hotlineDistrictAcceptanceListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(hotlineDistrictAcceptanceListener.getHotlineDistrictAcceptanceList());
    }
}
