package com.cqut.stack.bn.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.dao.MetadataMapper;
import com.cqut.stack.bn.exception.ToolsBusinessWarn;
import com.cqut.stack.bn.pojo.dto.metadata.QueryMetaDataListDTO;
import com.cqut.stack.bn.pojo.dto.metadata.SynchronizeDataDTO;
import com.cqut.stack.bn.pojo.dto.metadata.TableDTO;
import com.cqut.stack.bn.pojo.entity.DatabaseField;
import com.cqut.stack.bn.pojo.entity.DatabaseTable;
import com.cqut.stack.bn.pojo.vo.matadata.QueryMetaDataListVO;
import com.cqut.stack.bn.pojo.vo.matadata.TableInfo;
import com.cqut.stack.bn.service.DatabaseFieldService;
import com.cqut.stack.bn.service.DatabaseTableService;
import com.cqut.stack.bn.service.MetadataService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class MetadataServiceImpl implements MetadataService {

    @Resource
    private MetadataMapper metadataMapper;

    @Resource
    private DatabaseTableService databaseTableService;

    @Resource
    private DatabaseFieldService databaseFieldService;

    @Override
    public QueryMetaDataListVO queryMetaDataList(QueryMetaDataListDTO dto) {
        // 分页查询数据表idList
        PageHelper.startPage(dto.getPageNum(), dto.getPageSize());
        LambdaQueryWrapper<DatabaseTable> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.select(DatabaseTable::getId)
                .like(StringUtils.isNotEmpty(dto.getTableRemark()),DatabaseTable::getTableRemark,dto.getTableRemark())
                .eq(ObjectUtil.isNotEmpty(dto.getOwnerType()),DatabaseTable::getOwnerType,dto.getOwnerType());
        List<DatabaseTable> databaseTableList = databaseTableService.list(queryWrapper);
        PageInfo<DatabaseTable> pageInfo = new PageInfo<>(databaseTableList);
        List<Integer> tableIdList = databaseTableList.stream().map(DatabaseTable::getId).collect(Collectors.toList());
        dto.setTableIdList(tableIdList);

        // 查询每个数据表对应的数据字段
        List<TableInfo> tableInfoList = metadataMapper.queryMetaDataList(dto);
        QueryMetaDataListVO queryMetaDataListVO = new QueryMetaDataListVO();
        queryMetaDataListVO.setTableInfoList(tableInfoList);
        queryMetaDataListVO.setTotal(pageInfo.getTotal());
        return queryMetaDataListVO;
    }

    @Override
    public String generateTable(Integer tableId) {
        LambdaQueryWrapper<DatabaseTable> qwTable = new LambdaQueryWrapper<>();
        qwTable.eq(DatabaseTable::getId, tableId);
        DatabaseTable databaseTable = databaseTableService.getOne(qwTable);
        TableDTO table = BeanUtil.copyProperties(databaseTable, TableDTO.class);

        LambdaQueryWrapper<DatabaseField> qwField = new LambdaQueryWrapper<>();
        qwField.eq(DatabaseField::getTableId, tableId);

        table.setFields(databaseFieldService.list(qwField));

        return createSQL(table);
    }

    @Override
    public void synchronizeData(Integer tableId) {
        // 1、根据id查询同步表字段信息
        LambdaQueryWrapper<DatabaseField> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(DatabaseField::getTableId, tableId);
        List<DatabaseField> databaseFieldList = databaseFieldService.list(queryWrapper);
        Map<String,String> exchangeFieldMap = databaseFieldList.stream().collect(Collectors.toMap(DatabaseField::getRemoteFieldName,DatabaseField::getFieldName));

        // 2、调用第三方接口获取同步数据
        // 查询第三方接口地址
        DatabaseTable databaseTable = databaseTableService.getById(tableId);
        // 请求地址
        String url = databaseTable.getUrl();

        // 请求头
        HttpHeaders httpHeaders = new HttpHeaders();
        //httpHeaders.set("Authorization", "Bearer " + request.getHeader("Access-Token"));
        HttpEntity httpEntity = new HttpEntity(httpHeaders);

        RestTemplate restTemplate = new RestTemplate();
        ResponseEntity<String> response = restTemplate.exchange(
                url,
                HttpMethod.GET,
                httpEntity,
                String.class,
                1
        );

        JSONObject resultJsonObject = JSONUtil.parseObj(response.getBody());
        // 验证请求状态
        Integer code = resultJsonObject.getInt("code");
        if (code != 20000) {
            throw new ToolsBusinessWarn("发送请求失败：" + resultJsonObject.getStr("message"));
        }
        // 解析返回信息
        Map<String, Object> resultMap = JSON.parseObject(resultJsonObject.getStr("data"), Map.class);

        List<String> filedValueList = new ArrayList<>();
        StringBuilder fieldStr = null;

        for(Map.Entry<String, Object> map : resultMap.entrySet()){
            StringBuilder fieldValue = new StringBuilder("(");
            fieldStr = new StringBuilder(" (");
            Map<String,String> currentValue = (Map<String,String>)map.getValue();
            for(Map.Entry<String, String> filedMap : currentValue.entrySet()){
                // 将远程字段名与本地数据库字段名进行转换
                fieldStr.append(exchangeFieldMap.get(filedMap.getKey()));
                fieldStr.append(",");
                fieldValue.append(filedMap.getValue());
                fieldValue.append(",");
            }
            fieldStr.deleteCharAt(fieldStr.length() - 1);
            fieldValue.deleteCharAt(fieldStr.length() - 1);
            fieldStr.append("), ");
            filedValueList.add(fieldStr.toString());
        }
        // 循环拼接sql字符串，每次批量插入10条数据
        StringBuilder filedValues = new StringBuilder();
        for (int i = 0; i < filedValueList.size(); i++) {
            if(i/10 == 0 && i == filedValueList.size()){
                // 删除最后一个逗号
                filedValues.setLength(filedValues.length() - 1);
                metadataMapper.synchronizeData(fieldStr.toString(),filedValues.toString());
                filedValues = new StringBuilder();
            }
            filedValues.append(filedValueList.get(i));
        }
    }

    private String createSQL(TableDTO table){
        StringBuilder sb = new StringBuilder();
        sb.append("create table ");
        sb.append(table.getTableName());
        sb.append("(");
        sb.append("id int auto_increment, ");
        for (DatabaseField field : table.getFields()) {
            sb.append(field.getFieldName());
            sb.append(" ");
            if (field.getFieldType().equals("varchar")){
                sb.append("varchar(");
                sb.append(field.getFieldLength());
                sb.append(")");
            }else {
                sb.append(field.getFieldType());
            }
            sb.append(" ");
            if (field.getIsNull() == 0){
                sb.append("not null");
            }else {
                sb.append("null");
            }
            sb.append(" ");
            sb.append("comment");
            sb.append(" ");
            sb.append("'");
            sb.append(field.getRemark());
            sb.append("'");
            sb.append(",");
        }
        sb.append("primary key (id)");
        sb.append(")");
        sb.append(" ");
        sb.append("comment");
        sb.append(" ");
        sb.append("'");
        sb.append(table.getTableRemark());
        sb.append("'");
        sb.append(";");
        return sb.toString();
    }
}
