package com.cqut.stack.bn.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.fourOfficeInfo.FourOfficeImportDTO;
import com.cqut.stack.bn.pojo.dto.resourceTrade.GetResourceTransactionsDTO;
import com.cqut.stack.bn.pojo.dto.resourceTrade.ResourceTransactionImportDTO;
import com.cqut.stack.bn.pojo.entity.ResourceTransaction;
import com.cqut.stack.bn.dao.ResourceTransactionMapper;
import com.cqut.stack.bn.pojo.listener.FourOfficeListener;
import com.cqut.stack.bn.pojo.listener.ResourceTransactionListener;
import com.cqut.stack.bn.service.ResourceTransactionService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.time.LocalDate;
import java.util.List;

@Service
public class ResourceTransactionServiceImpl extends ServiceImpl<ResourceTransactionMapper, ResourceTransaction> implements ResourceTransactionService {

    @Resource
    private ResourceTransactionMapper resourceTransactionMapper;

    @Override
    public List<ResourceTransaction> getResourceTransactionList() {
        LambdaQueryWrapper<ResourceTransaction> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(ResourceTransaction::getTransactionDate, LocalDate.now());
        PageHelper.startPage(1, 10);
        return this.list(queryWrapper);
    }

    @Override
    public List<ResourceTransaction> getResourceTransactionsList(GetResourceTransactionsDTO dto) {
        LambdaQueryWrapper<ResourceTransaction> qw = Wrappers.lambdaQuery();
        qw.ge(ObjectUtil.isNotEmpty(dto.getStartDate()), ResourceTransaction::getTransactionDate, dto.getStartDate())
                .le(ObjectUtil.isNotEmpty(dto.getEndDate()), ResourceTransaction::getTransactionDate, dto.getEndDate());
        PageHelper.startPage(dto.getPageNum(), dto.getPageSize());
        return this.list(qw);
    }

    @Override
    public void importResourceTransactionDetail(ExcelImportDTO dto) {
        // 删除所有旧数据
        resourceTransactionMapper.deleteAll();
        ResourceTransactionListener resourceTransactionListener = new ResourceTransactionListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), ResourceTransactionImportDTO.class, resourceTransactionListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(resourceTransactionListener.getResourceTransactionList());
    }
}
