package com.cqut.stack.bn.service.impl;

import com.cqut.stack.bn.dao.RoleMapper;
import com.cqut.stack.bn.pojo.dto.permission.PermissionGetListInputDTO;
import com.cqut.stack.bn.pojo.dto.role.*;
import com.cqut.stack.bn.pojo.entity.role.Role;
import com.cqut.stack.bn.service.RoleService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class RoleServiceImpl implements RoleService {
    @Autowired
    private RoleMapper roleMapper;

    @Override
    public PageInfo<Role> getRoleList(PermissionGetListInputDTO inputDTO){
        PageHelper.startPage(inputDTO.getCurrentPage(),inputDTO.getPageSize());
        Page<Role> roleList = roleMapper.getRoleList();   //  取出角色列表


        return new PageInfo<>(roleList);
    }

    @Override
    public List<permissionDTO> getEditInfo(String roleId){
        EditInfo info = new EditInfo();
        List<permissionDTO> permissionDTOList = roleMapper.getPathList(roleId);

        return permissionDTOList;
    }

    @Override
    public boolean addRole(AddRoleDTO addRoleDTO){
        Role role = new Role();
        role.setRoleName(addRoleDTO.getRoleName());
        String roleId = UUID.randomUUID().toString().replaceAll("-","");
        role.setRoleId(roleId);

        ArrayList<AddRolePermissionDTO> rolePermissionList = new ArrayList<>();
        String[] permissionIds = addRoleDTO.getPermissionIds().split(",");
        for(int j = 0; j < permissionIds.length; j++){
            AddRolePermissionDTO rolePermissionDTO = new AddRolePermissionDTO();
            rolePermissionDTO.setRolePermissionId(UUID.randomUUID().toString().replaceAll("-", ""));
            rolePermissionDTO.setRoleId(roleId);
            rolePermissionDTO.setPermissionId(permissionIds[j]);

            rolePermissionList.add(rolePermissionDTO);
        }

        return roleMapper.addRole(role) > 0  && roleMapper.addRolePermission(rolePermissionList) > 0;
    }

    @Override
    public boolean editRole(RoleDTO roleDTO){

        ArrayList<AddRolePermissionDTO> rolePermissionList = new ArrayList<>();
        String[] permissionIds = roleDTO.getPermissionIds().split(",");
        for(int j = 0; j < permissionIds.length; j++){
            AddRolePermissionDTO rolePermissionDTO = new AddRolePermissionDTO();
            rolePermissionDTO.setRolePermissionId(UUID.randomUUID().toString().replaceAll("-", ""));
            rolePermissionDTO.setRoleId(roleDTO.getRoleId());
            rolePermissionDTO.setPermissionId(permissionIds[j]);

            rolePermissionList.add(rolePermissionDTO);
        }

        return roleMapper.editRole(roleDTO) > 0 && roleMapper.deleteRolePermission(roleDTO.getRoleId()) >= 0 && roleMapper.addRolePermission(rolePermissionList) > 0;
    }

    @Override
    public boolean deleteRole(String roleId){
        int deleteRolePermission = roleMapper.deleteRolePermission(roleId);
        int  deleteRole = roleMapper.deleteRole(roleId);
        return deleteRolePermission >= 0  && deleteRole > 0;
    }


    @Override
    public List<permissionDTO> getPermissionList(){
        // 选出所有的权限。
        List<permissionDTO> permissionDTOList = roleMapper.getPermissionList();

        return permissionDTOList;
    }
}
