package com.cqut.stack.bn.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.districtHandle.DistrictHandleImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDailyAcceptance.DateDTO;
import com.cqut.stack.bn.pojo.entity.TodayAcceptance;
import com.cqut.stack.bn.dao.TodayAcceptanceMapper;
import com.cqut.stack.bn.pojo.listener.DistrictHandleListener;
import com.cqut.stack.bn.pojo.listener.TodayAcceptanceListener;
import com.cqut.stack.bn.pojo.vo.todayAcceptance.GetTodayAcceptanceInfoVO;
import com.cqut.stack.bn.service.TodayAcceptanceService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.time.LocalDate;
import java.util.List;

@Service
public class TodayAcceptanceServiceImpl extends ServiceImpl<TodayAcceptanceMapper, TodayAcceptance> implements TodayAcceptanceService {

    @Resource
    private TodayAcceptanceMapper acceptanceMapper;

    @Override
    public GetTodayAcceptanceInfoVO getTodayAcceptanceInfo() {
        LambdaQueryWrapper<TodayAcceptance> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(TodayAcceptance::getStatDate, LocalDate.now());
        GetTodayAcceptanceInfoVO getTodayAcceptanceInfoVO = new GetTodayAcceptanceInfoVO();
        List<TodayAcceptance> todayAcceptanceList = this.list(queryWrapper);
        if(CollectionUtil.isEmpty(todayAcceptanceList))
            return null;
        BeanUtil.copyProperties(todayAcceptanceList.get(0),getTodayAcceptanceInfoVO);
        return getTodayAcceptanceInfoVO;
    }

    @Override
    public List<TodayAcceptance> getTodayAcceptance(DateDTO dateDTO) {
        LambdaQueryWrapper<TodayAcceptance> queryWrapper = Wrappers.lambdaQuery();
        if(dateDTO.getStartDate()!=null)
            queryWrapper.ge(TodayAcceptance::getStatDate,dateDTO.getStartDate());
        if(dateDTO.getEndDate()!=null)
            queryWrapper.le(TodayAcceptance::getStatDate,dateDTO.getEndDate());
        PageHelper.startPage(dateDTO.getPageNum(),dateDTO.getPageSize());
        return this.list(queryWrapper);
    }

    @Override
    public void importTodayAcceptance(ExcelImportDTO dto) {
        // 删除所有旧数据
        acceptanceMapper.deleteAll();
        TodayAcceptanceListener todayAcceptanceListener = new TodayAcceptanceListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), DistrictHandleImportDTO.class, todayAcceptanceListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(todayAcceptanceListener.getTodayAcceptancList());
    }
}
