package com.cqut.stack.bn.service.impl;

import com.cqut.stack.bn.service.UserService;
import com.cqut.stack.bn.dao.UserMapper;
import com.cqut.stack.bn.pojo.dto.user.*;
import com.cqut.stack.bn.pojo.entity.user.User;
import com.cqut.stack.bn.pojo.entity.user.UserRole;
import com.cqut.stack.bn.pojo.enums.UserStatus;
import com.cqut.stack.bn.pojo.global.PaginationDTO;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.UUID;

/**
 * @Author: 罗舒月
 * @Description: 用户管理界面
 * @Date: Create in 19:29 2019/3/31
 */
@Service
public class UserServiceImpl implements UserService {
    @Autowired
    private UserMapper userMapper;

    @Autowired
    private BCryptPasswordEncoder bCryptPasswordEncoder;

    /**
     * 新增用户并分配角色
     * @param insertUser
     * @return
     */
    @Override
    public Boolean insertUser(InsertUserInputDTO insertUser){
        if(userMapper.checkAccount(insertUser.getAccount()))
            return new Boolean(false);

        String userId = UUID.randomUUID().toString();
        String userRoleId = UUID.randomUUID().toString();

        User user = new User();
        BeanUtils.copyProperties(insertUser,user);
        user.setUserId(userId);
        user.setStatus(UserStatus.EFFECT.getCode());
        user.setPassword(bCryptPasswordEncoder.encode(user.getPassword()));

        Boolean isSuccess = userMapper.insertUser(user);
        if(isSuccess == true){
                UserRole userRole = new UserRole(userRoleId,userId,insertUser.getRoleId(),insertUser.getRemark());
                if(userMapper.addUserRole(userRole))
                    return true;
        }
        return false;
    }

    /**
     * 选取用户列表
     * @param data
     * @return
     */
    @Override
    public PageInfo<SelectUserListDTO> selectUserList(PaginationDTO data) {
        PageHelper.startPage(data.getPageNum(),data.getPageSize());
        Page<SelectUserListDTO> result = userMapper.selectUserList();
        return new PageInfo<>(result);
    }

    /**
     * 更改用户状态
     * @param userId
     * @return
     */
    @Override
    public Boolean changeUserStatus(String userId){
        return userMapper.changeUserStatus(userId);
    }

    /**
     * 更改用户的角色
     * @param input
     * @return
     */
    @Override
    public Boolean changeUserRole(ChangeUserRoleInputDTO input) {
        return userMapper.changeUserRole(input);
    }

    /**
     * 删除用户信息
     * @param userId
     * @return
     */
    @Override
    public Boolean deleteUser(String userId) {
        return userMapper.deleteUser(userId);
    }

    /**
     * 根据用户ID获得用户详细信息
     * @param userId
     * @return
     */
    @Override
    public SelectByUserIdDTO selectByUserId(String userId) {
        return userMapper.selectByUserId(userId);
    }

    /**
     * 获取角色列表
     * @return
     */
    @Override
    public List<SelectRoleListDTO> selectRoleList() {
        return userMapper.selectRoleList();
    }

    /**
     * 系统用户修改密码
     * @param input
     * @return
     */
    @Override
    public Boolean updatePassword(UpdatePasswordInputDTO input){
        input.setPassword(bCryptPasswordEncoder.encode(input.getPassword()));
        return userMapper.updatePassword(input);
    }
}
