package com.cqut.stack.bn.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.districtHandle.DistrictHandleImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDailyAcceptance.DateDTO;
import com.cqut.stack.bn.pojo.dto.wordOrderDetail.WordOrderDetailImportDTO;
import com.cqut.stack.bn.pojo.dto.workOrder.GetWorkOrderDetailDTO;
import com.cqut.stack.bn.pojo.entity.WordOrderDetail;
import com.cqut.stack.bn.dao.WordOrderDetailMapper;
import com.cqut.stack.bn.pojo.entity.WorkOrderCirculation;
import com.cqut.stack.bn.pojo.listener.DistrictHandleListener;
import com.cqut.stack.bn.pojo.listener.WordOrderDetailListener;
import com.cqut.stack.bn.service.WordOrderDetailService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;

@Service
public class WordOrderDetailServiceImpl extends ServiceImpl<WordOrderDetailMapper, WordOrderDetail> implements WordOrderDetailService {

    @Resource
    private WordOrderDetailMapper wordOrderDetailMapper;

    @Override
    public WordOrderDetail getWorkOrderDetail(GetWorkOrderDetailDTO dto) {
        LambdaQueryWrapper<WordOrderDetail> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(WordOrderDetail::getOrderId,dto.getId());
        List<WordOrderDetail> list = this.list(queryWrapper);
        if(ObjectUtil.isEmpty(list))
            return null;
        return list.get(0);
    }

    @Override
    public List<WordOrderDetail> getWordOrderDetail(DateDTO dateDTO) {
        LambdaQueryWrapper<WordOrderDetail> queryWrapper = new LambdaQueryWrapper<>();
        if(dateDTO.getStartDate()!=null)
            queryWrapper.ge(WordOrderDetail::getAcceptDate,dateDTO.getStartDate());
        if(dateDTO.getEndDate()!=null)
            queryWrapper.le(WordOrderDetail::getAcceptDate,dateDTO.getEndDate());
        PageHelper.startPage(dateDTO.getPageNum(), dateDTO.getPageSize());
        return this.list(queryWrapper);
    }

    @Override
    public void importWordOrderDetail(ExcelImportDTO dto) {
        // 删除所有旧数据
        wordOrderDetailMapper.deleteAll();
        WordOrderDetailListener wordOrderDetailListener = new WordOrderDetailListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), WordOrderDetailImportDTO.class, wordOrderDetailListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(wordOrderDetailListener.getHotlineAcceptanceList());
    }
}
