package com.cqut.stack.bn.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.districtHandle.DistrictHandleImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDailyAcceptance.DateDTO;
import com.cqut.stack.bn.pojo.dto.workOrderCirculation.GetWorkOrderCirculationDTO;
import com.cqut.stack.bn.pojo.dto.workOrderCirculation.WorkOrderCirculationImportDTO;
import com.cqut.stack.bn.pojo.entity.WorkOrderCirculation;
import com.cqut.stack.bn.dao.WorkOrderCirculationMapper;
import com.cqut.stack.bn.pojo.listener.DistrictHandleListener;
import com.cqut.stack.bn.pojo.listener.WorkOrderCirculationListener;
import com.cqut.stack.bn.service.WorkOrderCirculationService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;
import java.util.Objects;

@Service
public class WorkOrderCirculationServiceImpl extends ServiceImpl<WorkOrderCirculationMapper, WorkOrderCirculation> implements WorkOrderCirculationService {

    @Resource
    private WorkOrderCirculationMapper workOrderCirculationMapper;

    @Override
    public WorkOrderCirculation getWorkOrderCirculation(GetWorkOrderCirculationDTO dto) {
        LambdaQueryWrapper<WorkOrderCirculation> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(WorkOrderCirculation::getOrderId,dto.getId());
        List<WorkOrderCirculation> list = this.list(queryWrapper);
        if(ObjectUtil.isEmpty(list))
            return null;
        return list.get(0);
    }

    @Override
    public List<WorkOrderCirculation> getWorkOrderCirculationList(DateDTO dateDTO) {
        LambdaQueryWrapper<WorkOrderCirculation> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.ge(Objects.nonNull(dateDTO.getStartDate()),WorkOrderCirculation::getProcessTime,dateDTO.getStartDate())
                    .le(Objects.nonNull(dateDTO.getEndDate()),WorkOrderCirculation::getProcessTime,dateDTO.getEndDate());
        PageHelper.startPage(dateDTO.getPageNum(),dateDTO.getPageSize());
        return this.list(queryWrapper);
    }

    @Override
    public void importWorkOrderCirculationList(ExcelImportDTO dto) {
        // 删除所有旧数据
        workOrderCirculationMapper.deleteAll();
        WorkOrderCirculationListener workOrderCirculationListener = new WorkOrderCirculationListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), WorkOrderCirculationImportDTO.class, workOrderCirculationListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(workOrderCirculationListener.getHotlineAcceptanceList());
    }
}
