package com.cqut.stack.bn.service.impl;

import com.alibaba.excel.EasyExcel;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cqut.stack.bn.pojo.dto.base.ExcelImportDTO;
import com.cqut.stack.bn.pojo.dto.districtHandle.DistrictHandleImportDTO;
import com.cqut.stack.bn.pojo.dto.hotlineDailyAcceptance.DateDTO;
import com.cqut.stack.bn.pojo.dto.workOrder.GetWorkOrderResourceTypeDTO;
import com.cqut.stack.bn.pojo.dto.workOrder.WorkOrderImportDTO;
import com.cqut.stack.bn.pojo.entity.WorkOrder;
import com.cqut.stack.bn.dao.WorkOrderMapper;
import com.cqut.stack.bn.pojo.listener.DistrictHandleListener;
import com.cqut.stack.bn.pojo.listener.WorkOrderListener;
import com.cqut.stack.bn.pojo.vo.workOrder.GetWorkOrderResourceTypVO;
import com.cqut.stack.bn.service.WorkOrderService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.time.LocalDate;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class WorkOrderServiceImpl extends ServiceImpl<WorkOrderMapper, WorkOrder> implements WorkOrderService {

    @Resource
    private WorkOrderMapper workOrderMapper;

    @Override
    public List<WorkOrder> getWorkOrderList() {
        LambdaQueryWrapper<WorkOrder> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(WorkOrder::getOrderTime, LocalDate.now());
        PageHelper.startPage(1,10);
        return this.list(queryWrapper);
    }

    @Override
    public GetWorkOrderResourceTypVO getWorkOrderResourceType(GetWorkOrderResourceTypeDTO dto) {
        LambdaQueryWrapper<WorkOrder> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.like(WorkOrder::getOrderTime,dto.getYear());
        List<WorkOrder> list = this.list(queryWrapper);
        Map<String,List<WorkOrder>> orderTypeMap = list.stream().collect(Collectors.groupingBy(WorkOrder::getOrderType));
        Map<String,Integer> result = new HashMap<>();
        for(Map.Entry<String,List<WorkOrder>> map : orderTypeMap.entrySet()){
            result.put(map.getKey(),map.getValue().size());
        }
        GetWorkOrderResourceTypVO getWorkOrderResourceTypVO = new GetWorkOrderResourceTypVO();
        getWorkOrderResourceTypVO.setMap(result);
        return getWorkOrderResourceTypVO;
    }

    @Override
    public List<WorkOrder> getWorkOrder(DateDTO dateDTO) {
        LambdaQueryWrapper<WorkOrder> queryWrapper = Wrappers.lambdaQuery();
        if(dateDTO.getStartDate()!=null)
            queryWrapper.ge(WorkOrder::getOrderTime,dateDTO.getStartDate());
        if(dateDTO.getEndDate()!=null)
            queryWrapper.le(WorkOrder::getOrderTime,dateDTO.getEndDate());
        PageHelper.startPage(dateDTO.getPageNum(),dateDTO.getPageSize());
        return this.list(queryWrapper);
    }

    @Override
    public void importWorkOrder(ExcelImportDTO dto) {
        // 删除所有旧数据
        workOrderMapper.deleteAll();
        WorkOrderListener workOrderListener = new WorkOrderListener();
        try {
            EasyExcel.read(dto.getMultipartFile().getInputStream(), WorkOrderImportDTO.class, workOrderListener)
                    .headRowNumber(1).sheet().doRead();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.saveBatch(workOrderListener.getHotlineAcceptanceList());
    }
}
