package com.cqut.stack.bn.util;

import com.cqut.stack.bn.pojo.entity.Attachment;
import io.minio.*;
import io.minio.http.Method;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.*;;
import java.util.*;

@Slf4j
@Component
public class MinioUtil {

    @Resource
    private MinioClient minioClient;

    @Value("${minio.bucketName}")
    private String bucketName;

    @SneakyThrows
    public void deleteFile(String objectName){
        minioClient.removeObject(RemoveObjectArgs.builder()
                .bucket(bucketName)
                .object(objectName)
                .build());
    }

    @SneakyThrows
    public Attachment uploadFile(MultipartFile file) {
        Attachment attachment = new Attachment();
        String uuid = UUID.randomUUID().toString().replace("-", "");
        String objectName = uuid + "-" + file.getOriginalFilename();
        InputStream inputStream = file.getInputStream();
        minioClient.putObject(
                PutObjectArgs.builder()
                        .bucket(bucketName)
                        .object(objectName)
                        .stream(inputStream, file.getSize(), -1)
                        .contentType(file.getContentType())
                        .build()
        );
        attachment.setName(file.getOriginalFilename());
        attachment.setObjName(objectName);
        String fileUrl = this.getFileUrl(objectName);
        attachment.setPath(fileUrl);
        String[] split = Objects.requireNonNull(file.getOriginalFilename()).split("\\.");
        attachment.setType(split[split.length-1]);
        attachment.setSize(file.getSize());
        return attachment;
    }

    @SneakyThrows
    public String getFileUrl(String objectName) {
        // 查看文件地址
        return minioClient.getPresignedObjectUrl(
                GetPresignedObjectUrlArgs
                        .builder()
                        .bucket(bucketName)
                        .object(objectName)
                        .method(Method.GET)
                        .build());
    }
}


