package com.cqut.stack.bn.util.jsonResult;

import com.github.pagehelper.Page;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.beans.BeanUtils;

/**
 * ? 匹配任意数据类型
 *
 */
@Data
public class Result<T> {

    /**
     * 返回success或failure操作标识
     */
    @ApiModelProperty(value = "操作标识")
    private String type;

    /**
     * 国际化处理的返回JSON消息代码
     */
    @ApiModelProperty(value = "接口响应码 ,0为成功")
    private int code;

    /**
     * 国际化处理的返回JSON消息页面信息
     */
    @ApiModelProperty(value = "分页信息")
    private PageMessage pageMessage;

    /**
     * 国际化处理的返回JSON消息正文
     */
    @ApiModelProperty(value = "国际化处理的返回JSON消息正文")
    private String message;

    /**
     * 返回的数据
     */
    @ApiModelProperty(value = "返回的数据")
    private T result;

    /**
     * 操作成功与否枚举
     */
    public enum OPERATION_RESULT_TYPE {
        success , failure
    }

    /**
     * 操作成功，返回枚举类中的消息
     *
     * @param codeMessage 消息枚举
     */
    public static <T> Result<T> buildSuccessResult(CodeMessage codeMessage) {
        return new Result<>(OPERATION_RESULT_TYPE.success,
                codeMessage.getCode(), codeMessage.getMessage(),null);
    }

    /**
     * 操作成功，返回枚举类中的消息
     *
     *
     * @param result  返回的数据
     */
    public static <T> Result<T> buildSuccessResult(CodeMessage codeMessage, T result) {
        return new Result<>(OPERATION_RESULT_TYPE.success,
                codeMessage.getCode(), codeMessage.getMessage(),result);
    }

    /**
     * 操作失败，返回枚举类中的消息
     *
     * @param codeMessage 消息枚举
     */
    public static <T> Result<T> buildFailureResult(CodeMessage codeMessage) {
        return new Result<>(OPERATION_RESULT_TYPE.failure,
                codeMessage.getCode(), codeMessage.getMessage(),null);
    }

    /**
     * 操作失败，返回自定义错误消息
     *
     * @param message 错误消息
     */
    public static <T> Result<T> buildFailureParamResult(String message) {
        return new Result<>(OPERATION_RESULT_TYPE.failure,
                CodeMessage.E_ERROR.getCode(), message,null);
    }

    /**
     * 定义返回值
     */
    public Result(OPERATION_RESULT_TYPE type, int code, String message, T result) {
        this.type = type.name();
        this.code = code;
        this.message = message;
        if (result instanceof Page) {
            Page<Object> page = (Page<Object>) result;
            this.pageMessage = new PageMessage();
            this.pageMessage.setPrePage(page.getPageNum() - 1);
            this.pageMessage.setNextPage((page).getPageNum() + 1);
            BeanUtils.copyProperties(result,pageMessage);
        }
        this.result = result;
    }
}


